<?php

$LANG = array(
    'organization' => 'Organizacja',
    'name' => 'Nazwa',
    'website' => 'Strona internetowa',
    'work_phone' => 'Telefon służbowy',
    'address' => 'Adres',
    'address1' => 'Ulica',
    'address2' => 'Nr',
    'city' => 'Miasto',
    'state' => 'Województwo',
    'postal_code' => 'Kod pocztowy',
    'country_id' => 'Kraj',
    'contacts' => 'Kontakty',
    'first_name' => 'Imię',
    'last_name' => 'Nazwisko',
    'phone' => 'Telefon',
    'email' => 'Email',
    'additional_info' => 'Dodatkowe informacje',
    'payment_terms' => 'Warunki płatnicze',
    'currency_id' => 'Waluta',
    'size_id' => 'Wielkość firmy',
    'industry_id' => 'Branża',
    'private_notes' => 'Prywatne notatki',
    'invoice' => 'Faktura',
    'client' => 'Klient',
    'invoice_date' => 'Data Faktury',
    'due_date' => 'Termin',
    'invoice_number' => 'Numer Faktury',
    'invoice_number_short' => 'Faktura #',
    'po_number' => 'Numer zamówienia',
    'po_number_short' => 'Zamówienie #',
    'frequency_id' => 'Jak często',
    'discount' => 'Rabat',
    'taxes' => 'Podatki',
    'tax' => 'Podatek',
    'item' => 'Pozycja',
    'description' => 'Opis towaru / usługi',
    'unit_cost' => 'Cena j. netto',
    'quantity' => 'Ilość',
    'line_total' => 'Wartość',
    'subtotal' => 'Suma wartości netto',
    'paid_to_date' => 'Zapłacono dotychczas',
    'balance_due' => 'Do zapłaty',
    'invoice_design_id' => 'Motyw',
    'terms' => 'Warunki',
    'your_invoice' => 'Twoja faktura',
    'remove_contact' => 'Usuń kontakt',
    'add_contact' => 'Dodaj kontakt',
    'create_new_client' => 'Dodaj nowego klienta',
    'edit_client_details' => 'Edytuj dane klienta',
    'enable' => 'Aktywuj',
    'learn_more' => 'Więcej informacji',
    'manage_rates' => 'Zarządzaj stawkami',
    'note_to_client' => 'Informacja dla klienta',
    'invoice_terms' => 'Warunki do faktury',
    'save_as_default_terms' => 'Zapisz jako domyślne warunki',
    'download_pdf' => 'Pobierz PDF',
    'pay_now' => 'Zapłać teraz',
    'save_invoice' => 'Zapisz fakturę',
    'clone_invoice' => 'Skopiuj do Faktury',
    'archive_invoice' => 'Zarchiwizuj fakturę',
    'delete_invoice' => 'Usuń fakturę',
    'email_invoice' => 'Wyślij fakturę',
    'enter_payment' => 'Wprowadź płatność',
    'tax_rates' => 'Stawki podatkowe',
    'rate' => 'Stawka',
    'settings' => 'Ustawienia',
    'enable_invoice_tax' => 'Aktywuj możliwość ustawienia <b>podatku do faktury</b>',
    'enable_line_item_tax' => 'Aktywuj możliwość ustawienia <b>podatku do pozycji na fakturze</b>',
    'dashboard' => 'Pulpit',
    'dashboard_totals_in_all_currencies_help' => 'Dodaj :link nazwany ":name" by pokazać sumę używając uwspólnionej waluty.',
    'clients' => 'Klienci',
    'invoices' => 'Faktury',
    'payments' => 'Płatności',
    'credits' => 'Kredyty',
    'history' => 'Historia',
    'search' => 'Szukaj',
    'sign_up' => 'Zapisz się',
    'guest' => 'Gość',
    'company_details' => 'Dane firmy',
    'online_payments' => 'Płatności online',
    'notifications' => 'Powiadomienia',
    'import_export' => 'Import | Eksport danych',
    'done' => 'Gotowe',
    'save' => 'Zapisz',
    'create' => 'Utwórz',
    'upload' => 'Prześlij',
    'import' => 'Importuj',
    'download' => 'Pobierz',
    'cancel' => 'Anuluj',
    'close' => 'Zamknij',
    'provide_email' => 'Wprowadź poprawny e-mail',
    'powered_by' => 'Oparte na',
    'no_items' => 'Brak pozycji',
    'recurring_invoices' => 'Faktury odnawialne',
    'recurring_help' => 'Automatycznie wysyłaj klientom faktury co tydzień, dwa, miesiąc lub rok.
Użyj :MONTH, :QUARTER, :YEAR dla dynamicznych dat. Możesz też użyć zapisu matematycznego, np. :MONTH-1.
Przykłady dynamicznych zmiennych:
"Abonament na siłownie za miesiąc :MONTH" >> "Abonament za siłownię za miesiąc Lipiec"
":YEAR+1 roczna subskrypcja" >> "2015 roczna subskrypcja"
"Płatne z góry za kwartał :QUARTER+1" >> "Płatne z góry za kwartał Q2"',
    'recurring_quotes' => 'Powtarzalne wyceny',
    'in_total_revenue' => 'całkowity przychód',
    'billed_client' => 'obciążony klient',
    'billed_clients' => 'obciążeni klienci',
    'active_client' => 'aktywny klient',
    'active_clients' => 'aktywni klienci',
    'invoices_past_due' => 'Zaległe faktury',
    'upcoming_invoices' => 'Nadchodzące faktury',
    'average_invoice' => 'Średnia wartość',
    'archive' => 'Archiwum',
    'delete' => 'Usuń',
    'archive_client' => 'Zarchiwizuj klienta',
    'delete_client' => 'Usuń klienta',
    'archive_payment' => 'Zarchiwizuj płatność',
    'delete_payment' => 'Usuń płatność',
    'archive_credit' => 'Zarchiwizuj kredyt',
    'delete_credit' => 'Usuń kredyt',
    'show_archived_deleted' => 'Pokaż zarchiwizowane/usunięte',
    'filter' => 'Filtruj',
    'new_client' => 'Nowy klient',
    'new_invoice' => 'Nowa faktura',
    'new_payment' => 'Nowa płatność',
    'new_credit' => 'Wprowadź kredyt',
    'contact' => 'Kontakt',
    'date_created' => 'Data utworzenia',
    'last_login' => 'Ostatnie logowanie',
    'balance' => 'Saldo',
    'action' => 'Akcja',
    'status' => 'Status',
    'invoice_total' => 'Faktura ogółem',
    'frequency' => 'Częstotliwość',
    'range' => 'Zakres',
    'start_date' => 'Początkowa data',
    'end_date' => 'Końcowa data',
    'transaction_reference' => 'Numer referencyjny transakcji',
    'method' => 'Metoda',
    'payment_amount' => 'Kwota płatności',
    'payment_date' => 'Data płatności',
    'credit_amount' => 'Kwota kredytu',
    'credit_balance' => 'Saldo kredytowe',
    'credit_date' => 'Data kredytu',
    'empty_table' => 'Brak danych w tabeli',
    'select' => 'Wybierz',
    'edit_client' => 'Edytuj klienta',
    'edit_invoice' => 'Edytuj fakturę',
    'create_invoice' => 'Utwórz Fakturę',
    'enter_credit' => 'Wprowadź kredyt',
    'last_logged_in' => 'Ostatnie logowanie',
    'details' => 'Szczegóły',
    'standing' => 'Oczekujące',
    'credit' => 'Kredyt',
    'activity' => 'Dziennik aktywności',
    'date' => 'Data',
    'message' => 'Wiadomość',
    'adjustment' => 'Dostosowanie',
    'are_you_sure' => 'Jesteś pewny?',
    'payment_type_id' => 'Typ płatności',
    'amount' => 'Kwota',
    'work_email' => 'Email',
    'language_id' => 'Język',
    'timezone_id' => 'Strefa czasowa',
    'date_format_id' => 'Format daty',
    'datetime_format_id' => 'Format Data/Godzina',
    'users' => 'Użytkownicy',
    'localization' => 'Lokalizacja',
    'remove_logo' => 'Usuń logo',
    'logo_help' => 'Obsługiwane: JPEG, GIF i PNG',
    'payment_gateway' => 'Dostawca płatności',
    'gateway_id' => 'Dostawca',
    'email_notifications' => 'Powiadomienia mailowe',
    'email_sent' => 'Wyślij do mnie email, gdy faktura zostanie <b>wysłana</b>',
    'email_viewed' => 'Wyślij do mnie email, gdy faktura zostanie <b>wyświetlona</b>',
    'email_paid' => 'Wyślij do mnie email, gdy faktura zostanie <b>opłacona</b>',
    'site_updates' => 'Aktualizacje strony',
    'custom_messages' => 'Niestandardowe komunikaty',
    'default_email_footer' => 'Ustaw domyślny <b>podpis dla wiadomości email</b>',
    'select_file' => 'Wybierz plik',
    'first_row_headers' => 'Użyj pierwszego wiersza jako nagłówków',
    'column' => 'Kolumna',
    'sample' => 'Przykład',
    'import_to' => 'Zaimportuj do',
    'client_will_create' => 'klient będzie utworzony',
    'clients_will_create' => 'klienci będą utworzeni',
    'email_settings' => 'Ustawienia e-mail',
    'client_view_styling' => 'Dopasowanie widoku klienta',
    'pdf_email_attachment' => 'Załącz PDF',
    'custom_css' => 'Własny CSS',
    'import_clients' => 'Importuj dane klienta',
    'csv_file' => 'Plik CSV',
    'export_clients' => 'Eksportuj dane klienta',
    'created_client' => 'Klient został utworzony',
    'created_clients' => 'Utworzono :count klienta/klientów',
    'updated_settings' => 'Ustawienia zostały zaktualizowane',
    'removed_logo' => 'Logo zostało usunięte',
    'sent_message' => 'Wiadomość została wysłana',
    'invoice_error' => 'Pamiętaj, aby wybrać klienta i poprawić błędy',
    'limit_clients' => 'Przepraszamy, to przekracza limit :count klientów',
    'payment_error' => 'Wystąpił błąd w trakcie przetwarzania płatności. Prosimy spróbować później.',
    'registration_required' => 'Zarejestruj się, aby wysłać fakturę w wiadomości email',
    'confirmation_required' => 'Potwierdź swój adres emailowy, :link do ponownego wysłania emailu weryfikujacego.',
    'updated_client' => 'Klient został zaktualizowany',
    'archived_client' => 'Klient został zarchiwizowany',
    'archived_clients' => 'Zarchiwizowano :count klientów',
    'deleted_client' => 'Klient został usunięty',
    'deleted_clients' => 'Usunięto :count klientów',
    'updated_invoice' => 'Faktura została zaktualizowana',
    'created_invoice' => 'Faktura została utworzona',
    'cloned_invoice' => 'Faktura została sklonowana',
    'emailed_invoice' => 'Faktura została wysłana',
    'and_created_client' => 'i utworzono klienta',
    'archived_invoice' => 'Faktura została zarchiwizowana',
    'archived_invoices' => 'Zarchiwizowano :count faktury',
    'deleted_invoice' => 'Faktura została usunięta',
    'deleted_invoices' => 'Usunięto :count faktury',
    'created_payment' => 'Płatność została utworzona',
    'created_payments' => 'Utworzono :count płatność/płatności',
    'archived_payment' => 'Płatność zostałą zarchiwizowana',
    'archived_payments' => 'Zarchiwizowano :count płatności',
    'deleted_payment' => 'Płatność została usunięta',
    'deleted_payments' => 'Usunięto :count płatności',
    'applied_payment' => 'Zastosowano płatność',
    'created_credit' => 'Kredyt został utworzony',
    'archived_credit' => 'Kredyt zarchiwizowano',
    'archived_credits' => 'Zarchiwizowano :count kredyty/kredytów',
    'deleted_credit' => 'Kredyt został usunięty',
    'deleted_credits' => 'Usunięto :count kredyty/kredytów',
    'imported_file' => 'Plik został zaimportowany',
    'updated_vendor' => 'Zaktualizowano dostawcę',
    'created_vendor' => 'Dostawca został utworzony',
    'archived_vendor' => 'Dostawca został zarchiwizowany',
    'archived_vendors' => 'Zarchiwizowano :count dostawców',
    'deleted_vendor' => 'Dostawca został usunięty',
    'deleted_vendors' => 'Usunięto :count dostawców',
    'confirmation_subject' => 'Potwierdzenie rejestracji konta w Invoice Ninja',
    'confirmation_header' => 'Potwierdzenie rejestracji konta',
    'confirmation_message' => 'Proszę przejść do poniższego adresu, aby zweryfikować swoje konto.',
    'invoice_subject' => 'Nowa faktura :number od :account',
    'invoice_message' => 'Aby wyświetlić fakturę za :amount kliknij link poniżej.',
    'payment_subject' => 'Otrzymano płatność',
    'payment_message' => 'Dziękujemy za dokonanie płatności w kwocie :amount.',
    'email_salutation' => 'Drogi :name,',
    'email_signature' => 'Z wyrazami szacunku,',
    'email_from' => 'Zespół The Invoice Ninja',
    'invoice_link_message' => 'Aby wyświetlić fakturę kliknij link poniżej:',
    'notification_invoice_paid_subject' => 'Faktura :invoice zapłacona przez :client',
    'notification_invoice_sent_subject' => 'Faktura :invoice wysłana do :client',
    'notification_invoice_viewed_subject' => 'Faktura :invoice wyświetlona przez :client',
    'notification_invoice_paid' => 'Płatność na kwotę :amount została dokonana przez :client w ramach faktury :invoice.',
    'notification_invoice_sent' => 'Do :client wysłano email z fakturą :invoice na kwotę :amount.',
    'notification_invoice_viewed' => ':client wyświetlił fakturą :invoice na kwotę :amount.',
    'reset_password' => 'Możesz zresetować hasło do swojego konta klikając ten przycisk:',
    'secure_payment' => 'Bezpieczna płatność',
    'card_number' => 'Numer karty płatniczej',
    'expiration_month' => 'Miesiąc ważności ',
    'expiration_year' => 'Rok ważności ',
    'cvv' => 'Kod CVV',
    'logout' => 'Wyloguj się',
    'sign_up_to_save' => 'Zarejestruj się, aby zapisać swoją pracę',
    'agree_to_terms' => 'Zgadzam się na warunki :terms',
    'terms_of_service' => 'Warunki korzystania z Serwisu',
    'email_taken' => 'Podany adres email już istnieje',
    'working' => 'Wykonywanie',
    'success' => 'Sukces',
    'success_message' => 'Rejestracja udana! Proszę kliknąć link w mailu aktywacyjnym wysłanym na twój adres email.',
    'erase_data' => 'Twoje konto jest niezarejestrowane, ta operacja permanentnie usunie wszystkie Twoje dane.',
    'password' => 'Hasło',
    'pro_plan_product' => 'Plan Pro',
    'pro_plan_success' => 'Thanks for choosing Invoice Ninja\'s Pro plan!<p/>&nbsp;<br/>
                          <b>Next Steps</b><p/>A payable invoice has been sent to the email
                          address associated with your account. To unlock all of the awesome
                          Pro features, please follow the instructions on the invoice to pay
                          for a year of Pro-level invoicing.<p/>
                          Can\'t find the invoice? Need further assistance? We\'re happy to help
                          -- email us at contact@invoiceninja.com',
    'unsaved_changes' => 'Masz niezapisane zmiany',
    'custom_fields' => 'Dostosowane pola',
    'company_fields' => 'Pola firmy',
    'client_fields' => 'Pola klienta',
    'field_label' => 'Pola etykiety',
    'field_value' => 'Pola wartości',
    'edit' => 'Edytuj',
    'set_name' => 'Ustaw nazwę firmy',
    'view_as_recipient' => 'Wyświetl jako odbiorca',
    'product_library' => 'Biblioteka produktów',
    'product' => 'Produkt',
    'products' => 'Produkty',
    'fill_products' => 'Automatycznie uzupełniaj produkty',
    'fill_products_help' => 'Wybieranie produktu automatycznie <b>uzupełni opis i kwotę</b>',
    'update_products' => 'Automatycznie aktualizuj produkty',
    'update_products_help' => 'Zaktualizowanie faktury automatycznie <b>uaktualni produkt w bibliotece produktów</b>',
    'create_product' => 'Dodaj produkt',
    'edit_product' => 'Edytuj produkt',
    'archive_product' => 'Zarchiwizuj produkt',
    'updated_product' => 'Produkt został zaktualizowany',
    'created_product' => 'Produkt został utworzony',
    'archived_product' => 'Produkt został zarchiwizowany',
    'pro_plan_custom_fields' => ':link aby aktywować dostosowywanie pól poprzez dołączenie do planu Pro.',
    'advanced_settings' => 'Ustawienia zaawansowane',
    'pro_plan_advanced_settings' => ':link to enable the advanced settings by joining the Pro Plan',
    'invoice_design' => 'Motyw faktury',
    'specify_colors' => 'Wybierz kolory',
    'specify_colors_label' => 'Dopasuj kolory użyte w fakturze',
    'chart_builder' => 'Generator wykresów',
    'ninja_email_footer' => 'Utworzone przez :site | Twórz. Wysyłaj. Zarabiaj.',
    'go_pro' => 'Wybierz Pro',
    'quote' => 'Oferta',
    'quotes' => 'Oferty',
    'quote_number' => 'Numer oferty',
    'quote_number_short' => 'Oferta #',
    'quote_date' => 'Data oferty',
    'quote_total' => 'Suma oferty',
    'your_quote' => 'Twoja oferta',
    'total' => 'Suma',
    'clone' => 'Klonuj',
    'new_quote' => 'Nowa oferta',
    'create_quote' => 'Stwórz ofertę',
    'edit_quote' => 'Edytuj ofertę',
    'archive_quote' => 'Archiwizuj ofertę',
    'delete_quote' => 'Usuń ofertę',
    'save_quote' => 'Zapisz ofertę',
    'email_quote' => 'Wyślij ofertę',
    'clone_quote' => 'Skopiuj do Wyceny',
    'convert_to_invoice' => 'Konwertuj do faktury',
    'view_invoice' => 'Zobacz fakturę',
    'view_client' => 'Zobacz klienta',
    'view_quote' => 'Zobacz ofertę',
    'updated_quote' => 'Oferta została zaktualizowana',
    'created_quote' => 'Oferta została utworzona',
    'cloned_quote' => 'Oferta została sklonowana',
    'emailed_quote' => 'Oferta została wysłana',
    'archived_quote' => 'Oferta została zarchiwizowana',
    'archived_quotes' => 'Zarchiwizowano :count ofert',
    'deleted_quote' => 'Oferta została usunięta',
    'deleted_quotes' => 'Usunięto :count ofert',
    'converted_to_invoice' => 'Utworzono fakturę z oferty',
    'quote_subject' => 'Nowa wycena :number od :account',
    'quote_message' => 'Aby zobaczyć ofertę na kwotę :amount, kliknij w poniższy link.',
    'quote_link_message' => 'Aby zobaczyć ofertę dla klienta, kliknij w poniższy link:',
    'notification_quote_sent_subject' => 'Oferta :invoice została wysłana do :client',
    'notification_quote_viewed_subject' => 'Oferta :invoice została wyświetlona przez :client',
    'notification_quote_sent' => ':client otrzymał wiadomość email z ofertą :invoice na kwotę :amount.',
    'notification_quote_viewed' => ':client wyświetlił ofertę :invoice na kwotę :amount.',
    'session_expired' => 'Twoja sesja wygasła.',
    'invoice_fields' => 'Pola faktury',
    'invoice_options' => 'Opcje faktury',
    'hide_paid_to_date' => 'Ukryj pole "Zapłacono dotychczas"',
    'hide_paid_to_date_help' => 'Wyświetlaj "Zapłacono dotychczas" tylko przy tych fakturach, do których otrzymano płatność.',
    'charge_taxes' => 'Obciąż podatkami',
    'user_management' => 'Zarządzanie użytkownikami',
    'add_user' => 'Dodaj użytkownika',
    'send_invite' => 'Wyślij zaproszenie',
    'sent_invite' => 'Zaproszenie zostało wysłane',
    'updated_user' => 'Użytkownik został zaktualizowany',
    'invitation_message' => 'Zostałeś zaproszony przez :invitor. ',
    'register_to_add_user' => 'Zaloguj się, aby dodać użytkownika',
    'user_state' => 'Stan',
    'edit_user' => 'Edytuj użytkownika',
    'delete_user' => 'Usuń użytkownika',
    'active' => 'Aktywny',
    'pending' => 'Oczekuję',
    'deleted_user' => 'Użytkownik został usunięty',
    'confirm_email_invoice' => 'Czy na pewno chcesz wysłać emailem tę fakturę?',
    'confirm_email_quote' => 'Czy na pewno chcesz wysłać emailem tę ofertę?',
    'confirm_recurring_email_invoice' => 'Czy na pewno chcesz wysłać emailem tę fakturę?',
    'confirm_recurring_email_invoice_not_sent' => 'Napewno chcesz uruchomić odnawianie?',
    'cancel_account' => 'Anuluj konto',
    'cancel_account_message' => 'Ostrzeżenie: Nie można cofnąć tej operacji, wszystkie twoje dane zostaną usunięte.',
    'go_back' => 'Wstecz',
    'data_visualizations' => 'Wizualizacje danych',
    'sample_data' => 'Użyto przykładowych danych',
    'hide' => 'Ukryj',
    'new_version_available' => 'Nowa wersja dla :releases_link jest dostępna. Używasz wersji v:user_version, a najnowsza to v:latest_version',
    'invoice_settings' => 'Ustawienia faktury',
    'invoice_number_prefix' => 'Prefiks numeru faktury',
    'invoice_number_counter' => 'Licznik numeru faktury',
    'quote_number_prefix' => 'Prefiks numeru oferty',
    'quote_number_counter' => 'Licznik numeru oferty',
    'share_invoice_counter' => 'Udostępnij licznik faktur',
    'invoice_issued_to' => 'Faktura wystawiona dla',
    'invalid_counter' => 'Aby zapobiec możliwym konfliktom, proszę ustawić prefiks dla faktur lub ofert.',
    'mark_sent' => 'Oznacz jako wysłane',
    'gateway_help_1' => ':link, aby zarejestrować się w Authorize.net.',
    'gateway_help_2' => ':link, aby zarejestrować się w Authorize.net.',
    'gateway_help_17' => ':link, aby otrzymać sygnaturę PayPal API.',
    'gateway_help_27' => ':link do rejestracji na 2Checkout.com. Aby zapewnić śledzenie płatności ustaw :complete_link jako adres przekierowań w Konto > Zarządzanie stroną w portalu 2Checkout.',
    'gateway_help_60' => ':link aby stworzyć konto WePay.',
    'more_designs' => 'Więcej motywów',
    'more_designs_title' => 'Dodatkowe motywy faktur',
    'more_designs_cloud_header' => 'Więcej motywów faktur w wersji PRO',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Kup',
    'bought_designs' => 'Dodatkowe motywy faktur zostały dodane',
    'sent' => 'Wysłane',
    'vat_number' => 'Numer NIP',
    'timesheets' => 'Ewidencja czasu',
    'payment_title' => 'Enter Your Billing Address and Credit Card information',
    'payment_cvv' => '*to 3 lub 4 cyfrowy kod na odwrocie twojej karty płatnicznej',
    'payment_footer1' => '*Billing address must match address associated with credit card.',
    'payment_footer2' => '*Please click "PAY NOW" only once - transaction may take up to 1 minute to process.',
    'id_number' => 'REGON',
    'white_label_link' => 'White label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'Successfully enabled white label license',
    'white_labeled' => 'White labeled',
    'restore' => 'Przywróć',
    'restore_invoice' => 'Przywróć fakturę',
    'restore_quote' => 'Przywróć ofertę',
    'restore_client' => 'Przywróć klienta',
    'restore_credit' => 'Przywróć kredyt',
    'restore_payment' => 'Przywróć płatność',
    'restored_invoice' => 'Faktura została przywrócona',
    'restored_quote' => 'Oferta została przywrócona',
    'restored_client' => 'Klient został przywrócony',
    'restored_payment' => 'Płatność została przywrócona',
    'restored_credit' => 'Kredyt został przywrócony',
    'reason_for_canceling' => 'Help us improve our site by telling us why you\'re leaving.',
    'discount_percent' => 'Procent',
    'discount_amount' => 'Kwota',
    'invoice_history' => 'Historia faktury',
    'quote_history' => 'Historia oferty',
    'current_version' => 'Aktualna wersja',
    'select_version' => 'Wybierz wersję',
    'view_history' => 'Zobacz historię',
    'edit_payment' => 'Edytuj płatność',
    'updated_payment' => 'Płatność została zaktualizowana',
    'deleted' => 'Usunięte',
    'restore_user' => 'Przywróć użytkownika',
    'restored_user' => 'Użytkownik został przywrócony',
    'show_deleted_users' => 'Pokaż usuniętych użytkowników',
    'email_templates' => 'Szablony e-mail',
    'invoice_email' => 'Email faktury',
    'payment_email' => 'Email płatności',
    'quote_email' => 'Email oferty',
    'reset_all' => 'Resetuj wszystko',
    'approve' => 'Zatwierdź',
    'token_billing_type_id' => 'Token Płatności',
    'token_billing_help' => 'Pozwala zapisywać szczegóły płatności z WePay, Stripe, Braintree lub GoCardless.',
    'token_billing_1' => 'Wyłączone',
    'token_billing_2' => 'Opt-in - checkbox is shown but not selected',
    'token_billing_3' => 'Opt-out - checkbox is shown and selected',
    'token_billing_4' => 'Zawsze',
    'token_billing_checkbox' => 'Zapisz dane karty kredytowej',
    'view_in_gateway' => 'Zobacz w :gateway',
    'use_card_on_file' => 'Użyj zapisanej karty',
    'edit_payment_details' => 'Edytuj szczegóły płatności',
    'token_billing' => 'Zapisz dane karty',
    'token_billing_secure' => 'Te dane są bezpiecznie zapisywane dzięki :stripe_link',
    'support' => 'Wsparcie',
    'contact_information' => 'Dane kontaktowe',
    '256_encryption' => 'Szyfrowanie 256-bitowe.',
    'amount_due' => 'Należności',
    'billing_address' => 'Adres rozliczeniowy',
    'billing_method' => 'Metoda płatności',
    'order_overview' => 'Podgląd zamówienia',
    'match_address' => '*Adres musi być taki sam, jak ten związany z kartą płatniczą.',
    'click_once' => '*Proszę kliknąć "ZAPŁAC TERAZ" tylko raz - przetwarzanie transakcji może zająć do 1 minuty.',
    'invoice_footer' => 'Stopka faktury',
    'save_as_default_footer' => 'Zapisz jako domyślną stopkę',
    'token_management' => 'Zarządanie tokenem',
    'tokens' => 'Tokeny',
    'add_token' => 'Dodaj token',
    'show_deleted_tokens' => 'Pokaż usunięte tokeny',
    'deleted_token' => 'Token został usunięty',
    'created_token' => 'Token został utworzony',
    'updated_token' => 'Token został zaktualizowany',
    'edit_token' => 'Edytuj token',
    'delete_token' => 'Usuń token',
    'token' => 'Token',
    'add_gateway' => 'Dodaj dostawcę płatności',
    'delete_gateway' => 'Usuń dostawcę płatności',
    'edit_gateway' => 'Edytuj dostawcę płatności',
    'updated_gateway' => 'Dostawca płatności został zaktualizowany.',
    'created_gateway' => 'Dostawca płatności został utworzony',
    'deleted_gateway' => 'Dostawca płatności został usunięty',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Karta kredytowa',
    'change_password' => 'Zmień hasło',
    'current_password' => 'Aktualne hasło',
    'new_password' => 'Nowe hasło',
    'confirm_password' => 'Potwierdź hasło',
    'password_error_incorrect' => 'Hasło jest nieprawidłowe.',
    'password_error_invalid' => 'Nowe hasło jest nieprawidłowe.',
    'updated_password' => 'Hasło zostało zaktualizowane',
    'api_tokens' => 'Tokeny API',
    'users_and_tokens' => 'Użytkownicy i tokeny',
    'account_login' => 'Logowanie',
    'recover_password' => 'Odzyskaj swoje hasło',
    'forgot_password' => 'Zapomniałeś hasło?',
    'email_address' => 'Adres email',
    'lets_go' => 'Zaczynamy',
    'password_recovery' => 'Przywracanie hasła',
    'send_email' => 'Wyślij email',
    'set_password' => 'Ustaw hasło',
    'converted' => 'Skonwertowano',
    'email_approved' => 'Wyślij email, kiedy oferta będzie <b>zatwierdzona</b>',
    'notification_quote_approved_subject' => 'Oferta :invoice została zatwierdzona przez :client',
    'notification_quote_approved' => 'Klient :client zatwierdził ofertę :invoice na kwotę :amount.',
    'resend_confirmation' => 'Wyślij ponownie email potwierdzający',
    'confirmation_resent' => 'Email potwierdzający został wysłany',
    'gateway_help_42' => ':link to sign up for BitPay.<br/>Note: use a Legacy API Key, not an API token.',
    'payment_type_credit_card' => 'Karta kredytowa',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Baza wiedzy',
    'partial' => 'Zaliczka/Opł.część',
    'partial_remaining' => ':partial z :balance',
    'more_fields' => 'Więcej pól',
    'less_fields' => 'Mniej pól',
    'client_name' => 'Nazwa klienta',
    'pdf_settings' => 'Ustawienia PDF',
    'product_settings' => 'Ustawienia produktu',
    'auto_wrap' => 'Zawijaj wiersze',
    'duplicate_post' => 'Warning: the previous page was submitted twice. The second submission had been ignored.',
    'view_documentation' => 'Zobacz dokumentację',
    'app_title' => 'Free Open-Source Online Invoicing',
    'app_description' => 'Invoice Ninja to bezpłatne, otwarte rozwiązanie służące do fakturowania i billingu. Przy jego pomocy, możesz w prosty sposób tworzyć i wysyłać piękne faktury z dowolnego urządzenia z dostępem do internetu. Twoi klienci mogą drukować Twoje faktury, ściągać je w formacie PDF, a nawet płacić za nie online prost z systemu',
    'rows' => 'wierszy',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdomena',
    'provide_name_or_email' => 'Proszę wprowadzić nazwę lub adres email',
    'charts_and_reports' => 'Raporty i wykresy',
    'chart' => 'Wykres',
    'report' => 'Raport',
    'group_by' => 'Grupuj według',
    'paid' => 'Zapłacone',
    'enable_report' => 'Raport',
    'enable_chart' => 'Wykres',
    'totals' => 'Suma',
    'run' => 'Uruchom',
    'export' => 'Eksport',
    'documentation' => 'Dokumentacja',
    'zapier' => 'Zapier',
    'recurring' => 'Odnawialne',
    'last_invoice_sent' => 'Ostatnią fakturę wysłano :date',
    'processed_updates' => 'Pomyślnie zakończono aktualizację',
    'tasks' => 'Zadania',
    'new_task' => 'Nowe zadanie',
    'start_time' => 'Czas rozpoczęcia',
    'created_task' => 'Pomyślnie utworzono zadanie',
    'updated_task' => 'Pomyślnie zaktualizowano zadanie',
    'edit_task' => 'Edytuj zadanie',
    'clone_task' => 'Kopiuj zadanie',
    'archive_task' => 'Archiwizuj zadanie',
    'restore_task' => 'Przywróć zadanie',
    'delete_task' => 'Usuń zadanie',
    'stop_task' => 'Zatrzymaj zadanie',
    'time' => 'Czas',
    'start' => 'Rozpocznij',
    'stop' => 'Zatrzymaj',
    'now' => 'Teraz',
    'timer' => 'Odliczanie czasu',
    'manual' => 'Wprowadź ręcznie',
    'date_and_time' => 'Data i czas',
    'second' => 'sekunda',
    'seconds' => 'Sekundy',
    'minute' => 'Minuta',
    'minutes' => 'Minuty',
    'hour' => 'Godzina',
    'hours' => 'Godziny',
    'task_details' => 'Szczegóły zadania',
    'duration' => 'Czas trwania',
    'time_log' => 'Rejestr czasu',
    'end_time' => 'Zakończono',
    'end' => 'Koniec',
    'invoiced' => 'Zafakturowano',
    'logged' => 'Zapisano',
    'running' => 'W trakcie',
    'task_error_multiple_clients' => 'Zadania nie mogą należeć do różnych klientów',
    'task_error_running' => 'Proszę wcześniej zakończyć wykonywanie zadania.',
    'task_error_invoiced' => 'Zadania zostały już ujęte zafakturowane.',
    'restored_task' => 'Zadanie zostało przywrócone',
    'archived_task' => 'Zadania zostało zarchiwizowane',
    'archived_tasks' => 'Zarchiwizowano :count zadania/zadań',
    'deleted_task' => 'Usunięto zadanie',
    'deleted_tasks' => 'Usunięto :count zadania/zadań',
    'create_task' => 'Stwórz zadanie',
    'stopped_task' => 'Zakończono wykonywanie zadania',
    'invoice_task' => 'Fakturuj zadanie',
    'invoice_labels' => 'Etykiety Faktury',
    'prefix' => 'Prefiks',
    'counter' => 'Licznik',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link to sign up for Dwolla',
    'partial_value' => 'Must be greater than zero and less than the total',
    'more_actions' => 'Więcej działań',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Upgrade Now!',
    'pro_plan_feature1' => 'Create Unlimited Clients',
    'pro_plan_feature2' => 'Access to 10 Beautiful Invoice Designs',
    'pro_plan_feature3' => 'Custom URLs - "YourBrand.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Remove "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Multi-user Access & Activity Tracking',
    'pro_plan_feature6' => 'Tworzy oferty i faktury pro-forma',
    'pro_plan_feature7' => 'Customize Invoice Field Titles & Numbering',
    'pro_plan_feature8' => 'Opcja dołączania plików PDF do wiadomości email wysyłanych do klientów. ',
    'resume' => 'Wznów',
    'break_duration' => 'Zatrzymaj',
    'edit_details' => 'Edytuj szczegóły',
    'work' => 'Praca',
    'timezone_unset' => 'Please :link to set your timezone',
    'click_here' => 'kliknij tutaj',
    'email_receipt' => 'Wyślij potwierdzenie zapłaty do klienta',
    'created_payment_emailed_client' => 'Stworzono płatność i wysłano email do klienta',
    'add_company' => 'Dodaj firmę',
    'untitled' => 'Bez nazwy',
    'new_company' => 'Nowa firma',
    'associated_accounts' => 'Połączono konta',
    'unlinked_account' => 'Rozłączono konta',
    'login' => 'Zaloguj',
    'or' => 'lub',
    'email_error' => 'Wystąpił problem w trakcie wysyłania wiadomości email',
    'confirm_recurring_timing' => 'Uwaga: wiadomości email wysyłane są o równych godzinach.',
    'confirm_recurring_timing_not_sent' => 'Uwaga: faktury są tworzone na początku każdej godziny.',
    'payment_terms_help' => 'Ustaw domyślny <b>termin zapłaty faktury</b>',
    'unlink_account' => 'Odepnij konto',
    'unlink' => 'Odepnij',
    'show_address' => 'Pokaż adres',
    'show_address_help' => 'Wymagaj od klienta podania adresu rozliczeniowego',
    'update_address' => 'Aktualizuj adres',
    'update_address_help' => 'Zaktualizuj dane adresowe klienta na podstawie dostarczonych informacji',
    'times' => 'Razy/Okresy',
    'set_now' => 'Ustaw na teraz',
    'dark_mode' => 'Tryb ciemny',
    'dark_mode_help' => 'Użyj ciemnego tła dla bocznego menu',
    'add_to_invoice' => 'Dodaj do faktury :invoice',
    'create_new_invoice' => 'Utwórz nową fakturę',
    'task_errors' => 'Proszę skoryguj nakładające się czasy',
    'from' => 'Od',
    'to' => 'Do',
    'font_size' => 'Rozmiar fonta',
    'primary_color' => 'Główny kolor',
    'secondary_color' => 'Dodatkowy kolor',
    'customize_design' => 'Dostosuj motyw',
    'content' => 'Zawartość',
    'styles' => 'Style',
    'defaults' => 'Domyślne',
    'margins' => 'Marginesy',
    'header' => 'Nagłówek',
    'footer' => 'Stopka',
    'custom' => 'Dostosowanie',
    'invoice_to' => 'Faktura do',
    'invoice_no' => 'Faktura Nr',
    'quote_no' => 'Oferta Nr',
    'recent_payments' => 'Ostatnie płatności',
    'outstanding' => 'Zaległości',
    'manage_companies' => 'Zarządzaj firmami',
    'total_revenue' => 'Całkowity dochód',
    'current_user' => 'Aktualny użytkownik',
    'new_recurring_invoice' => 'Nowa faktura odnawialna',
    'recurring_invoice' => 'Odnawialna faktura',
    'new_recurring_quote' => 'Nowa powtarzalna wycena',
    'recurring_quote' => 'Powtarzalna wycena',
    'recurring_too_soon' => 'It\'s too soon to create the next recurring invoice, it\'s scheduled for :date',
    'created_by_invoice' => 'Utworzona przez :invoice',
    'primary_user' => 'Główny użytkownik',
    'help' => 'Pomoc',
    'customize_help' => 'Używamy :pdfmake_link by projektować faktury deklaratywnie. PDFMake :playground_link pozwala przetestować funkcjonalności tego rozwiązania. Jeśli potrzebujesz pomocy z tym rozwiązaniem napisz na naszym forum :forum_link.',
    'playground' => 'piaskownica',
    'support_forum' => 'forum wsparcia',
    'invoice_due_date' => 'Termin Płatności',
    'quote_due_date' => 'Ważny do',
    'valid_until' => 'Ważny do',
    'reset_terms' => 'Resetuj warunki',
    'reset_footer' => 'Resetuj stopkę',
    'invoice_sent' => ':count wysłana faktura ',
    'invoices_sent' => ':count wysłanych faktur',
    'status_draft' => 'Wersja robocza',
    'status_sent' => 'Wysłano',
    'status_viewed' => 'Wyświetlono',
    'status_partial' => 'Zaliczka/Opłacono część',
    'status_paid' => 'Zapłacono',
    'status_unpaid' => 'Nie zapłacono',
    'status_all' => 'Wszystkie',
    'show_line_item_tax' => 'Wyświetl <b>podatki w tej samej linii</b> co produkt/usługa.',
    'iframe_url' => 'Strona internetowa',
    'iframe_url_help1' => 'Skopiuj następujący kod na swoją stronę.',
    'iframe_url_help2' => 'Możesz przetestować tę funkcję klikając \'Zobacz jako odbiorca\' przy fakturze.',
    'auto_bill' => 'Płatność Automatyczna',
    'military_time' => '24 godzinny czas',
    'last_sent' => 'Ostatnio wysłano',
    'reminder_emails' => 'Przypomnienia emailowe',
    'quote_reminder_emails' => 'Email przypomnienia o ofercie',
    'templates_and_reminders' => 'Szablony i przypomnienia',
    'subject' => 'Temat',
    'body' => 'Treść',
    'first_reminder' => 'Pierwsze przypomnienie',
    'second_reminder' => 'Drugie przypomnienie',
    'third_reminder' => 'Trzecie przypomnienie',
    'num_days_reminder' => 'Dni po terminie płatności',
    'reminder_subject' => 'Przypomienie: Faktura :invoice od :account',
    'reset' => 'Reset',
    'invoice_not_found' => 'Żądana faktura nie jest dostępna',
    'referral_program' => 'Program referencyjny',
    'referral_code' => 'Referencyjny URL',
    'last_sent_on' => 'Ostatnio wysłano: :date',
    'page_expire' => 'Ta strona wkrótce wygaśnie, :click_here aby kontynuować pracę',
    'upcoming_quotes' => 'Nadchodzące oferty',
    'expired_quotes' => 'Wygasłe oferty',
    'sign_up_using' => 'Zarejestruj się przy użyciu',
    'invalid_credentials' => 'Niepoprawne dane logowania',
    'show_all_options' => 'Pokaż wszystkie opcje',
    'user_details' => 'Dane użytkownika',
    'oneclick_login' => 'Połączone konto',
    'disable' => 'Wyłącz',
    'invoice_quote_number' => 'Numery faktur i ofert',
    'invoice_charges' => 'Dopłaty do faktur',
    'notification_invoice_bounced' => 'Nie byliśmy w stanie dostarczyć faktury :invoice do :contact.',
    'notification_invoice_bounced_subject' => 'Brak możliwości dostarczenia faktury :invoice',
    'notification_quote_bounced' => 'Nie byliśmy w stanie dostarczyć oferty :invoice do :contact.',
    'notification_quote_bounced_subject' => 'Brak możliwości dostarczenia oferty :invoice',
    'custom_invoice_link' => 'Dostosowanie linku do faktury',
    'total_invoiced' => 'Suma z faktur',
    'open_balance' => 'Otwarte saldo',
    'verify_email' => 'Proszę kliknąć link aktywacyjny przesłany w wiadomości email, aby zweryfikować swój adres email.',
    'basic_settings' => 'Ustawienia podstawowe',
    'pro' => 'Pro',
    'gateways' => 'Dostawcy płatności',
    'next_send_on' => 'Wyślij ponownie: :date',
    'no_longer_running' => 'Harmonogram dla tej faktury nie został włączony',
    'general_settings' => 'Ustawienia ogólne',
    'customize' => 'Dostosuj',
    'oneclick_login_help' => 'Connect an account to login without a password',
    'referral_code_help' => 'Earn money by sharing our app online',
    'enable_with_stripe' => 'Aktywuj | Wymaga Stripe',
    'tax_settings' => 'Ustawienia podatków',
    'create_tax_rate' => 'Dodaj stawkę podatkową',
    'updated_tax_rate' => 'Successfully updated tax rate',
    'created_tax_rate' => 'Successfully created tax rate',
    'edit_tax_rate' => 'Edytuj stawkę podatkową',
    'archive_tax_rate' => 'Archiwizuj stawkę podatkową',
    'archived_tax_rate' => 'Zarchiwizowano stawkę podatkową',
    'default_tax_rate_id' => 'Domyśłna stawka podatkowa',
    'tax_rate' => 'Stawka podatkowa',
    'recurring_hour' => 'Okresowa godzina',
    'pattern' => 'Wzór',
    'pattern_help_title' => 'Wzór pomoc',
    'pattern_help_1' => 'Stwórz numery poprzez definicje wzoru',
    'pattern_help_2' => 'Dostępne zmienne:',
    'pattern_help_3' => 'Na przykład, :example będzie skonwertowane do :value',
    'see_options' => 'Zobacz opcje',
    'invoice_counter' => 'Licznik faktur',
    'quote_counter' => 'Licznik ofert',
    'type' => 'Typ',
    'activity_1' => ':user stworzył klienta :client',
    'activity_2' => ':user zarchiwizował klienta :client',
    'activity_3' => ':user usunął klienta :client',
    'activity_4' => ':user stworzył fakturę :invoice',
    'activity_5' => ':user zaktualizował fakturę :invoice',
    'activity_6' => ':user emailed invoice :invoice for :client to :contact',
    'activity_7' => ':contact viewed invoice :invoice for :client',
    'activity_8' => ':user zarchiwizował fakturę :invoice',
    'activity_9' => ':user usunął fakturę :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user zaktualizował płatność :payment',
    'activity_12' => ':user zarchiwizował płatność :payment',
    'activity_13' => ':user usunął płatność :payment',
    'activity_14' => ':user wprowadził kredyt :credit',
    'activity_15' => ':user zaktualizował kredyt :credit ',
    'activity_16' => ':user zarchiwizował kredyt :credit',
    'activity_17' => ':user usunął kredyt :credit ',
    'activity_18' => ':user stworzył ofertę :quote',
    'activity_19' => ':user zakatualizował ofertę :quote',
    'activity_20' => ':user emailed quote :quote for :client to :contact',
    'activity_21' => ':contact wyświetlił ofertę :quote',
    'activity_22' => ':user zarchiwizował ofertę :quote',
    'activity_23' => ':user usunął ofertę :quote',
    'activity_24' => ':user przywrócił ofertę :quote',
    'activity_25' => ':user przywrócił fakturę :invoice',
    'activity_26' => ':user przywrócił klienta :client',
    'activity_27' => ':user przywrócił płatność :payment',
    'activity_28' => ':user przywrócił kredyt :credit',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user utworzył dostawcę :vendor',
    'activity_31' => ':user zarchiwizował dostawcę :vendor',
    'activity_32' => ':user usunął dostawcę :vendor',
    'activity_33' => ':user przywrócił dostawcę :vendor',
    'activity_34' => ':user utworzył wydatek :expense',
    'activity_35' => ':user zarchiwizował wydatek :expense',
    'activity_36' => ':user usunął wydatek :expense',
    'activity_37' => ':user przywrócił wydatek :expense',
    'activity_42' => ':user stworzył zadanie :task',
    'activity_43' => ':user zaktualizował zadanie :task',
    'activity_44' => ':user zarchiwizował zadanie :task',
    'activity_45' => ':user usunął zadanie :task',
    'activity_46' => ':user przywrócił zadanie :task',
    'activity_47' => ':user zaktualizował wydatek :expense',
    'activity_48' => ':user zaktualizował zgłoszenie :ticket',
    'activity_49' => ':user zamknął zgłoszenie :ticket',
    'activity_50' => ':user połączył zgłoszenie :ticket',
    'activity_51' => ':user rozdzielił zgłoszenie :ticket',
    'activity_52' => ':contact otworzył zgłoszenie :ticket',
    'activity_53' => ':contact otworzył ponownie zgłoszenie :ticket',
    'activity_54' => ':user  otworzył zgłoszenie :ticket ponownie ',
    'activity_55' => ':contact odpowiedział w zgłoszeniu :ticket',
    'activity_56' => ':user oglądał zgłoszenie :ticket',

    'payment' => 'Płatność',
    'system' => 'System',
    'signature' => 'Podpis e-mail',
    'default_messages' => 'Domyślne wiadomości',
    'quote_terms' => 'Warunki oferty',
    'default_quote_terms' => 'Domyślne warunki oferty',
    'default_invoice_terms' => 'Domyślne warunki faktury',
    'default_invoice_footer' => 'Domyślna stopka faktury',
    'quote_footer' => 'Stopka oferty',
    'free' => 'Darmowe',
    'quote_is_approved' => 'Zaakceptowano pomyślnie',
    'apply_credit' => 'Zastosuj kredyt',
    'system_settings' => 'Ustawienia systemowe',
    'archive_token' => 'Archiwizuj token',
    'archived_token' => 'Token został zarchiwizowany',
    'archive_user' => 'Archiwizuj użytkownika',
    'archived_user' => 'Użytkownik został zarchiwizowany',
    'archive_account_gateway' => 'Usuń dostawcę płatności',
    'archived_account_gateway' => 'Zarchiwizowano dostawcę płatności',
    'archive_recurring_invoice' => 'Zarchiwizuj odnawialną fakturę',
    'archived_recurring_invoice' => 'Odnawialna faktura została zarchiwizowana',
    'delete_recurring_invoice' => 'Usuń odnawialną fakturę',
    'deleted_recurring_invoice' => 'Odnawialna faktura została usunięta.',
    'restore_recurring_invoice' => 'Przywróć odnawialną fakturę',
    'restored_recurring_invoice' => 'Odnawialna faktura została przywrócona',
    'archive_recurring_quote' => 'Archiwizuj powtarzającą się wycenę',
    'archived_recurring_quote' => 'Wycena powtarzająca się została zarchiwizowana pomyślnie',
    'delete_recurring_quote' => 'Skasuj powtarzalną wycenę',
    'deleted_recurring_quote' => 'Powtarzalna wycena skasowana pomyślnie',
    'restore_recurring_quote' => 'Odtwórz powtarzalną wycenę',
    'restored_recurring_quote' => 'Powtarzalna wycena odtworzona pomyślnie',
    'archived' => 'Zarchiwizowano',
    'untitled_account' => 'Firma bez nazwy',
    'before' => 'Przed',
    'after' => 'Po',
    'reset_terms_help' => 'Przywróć domyślne warunki dla konta',
    'reset_footer_help' => 'Przywróć domyślną stopkę dla konta',
    'export_data' => 'Eksportuj dane',
    'user' => 'Użytkownik',
    'country' => 'Kraj',
    'include' => 'Dołącz',
    'logo_too_large' => 'Your logo is :size, for better PDF performance we suggest uploading an image file less than 200KB',
    'import_freshbooks' => 'Import From FreshBooks',
    'import_data' => 'Importuj dane',
    'source' => 'Źródło',
    'csv' => 'CSV',
    'client_file' => 'Plik klienta',
    'invoice_file' => 'Plik faktury',
    'task_file' => 'Plik zadania',
    'no_mapper' => 'Brak poprawnego mapowania dla tego pliku',
    'invalid_csv_header' => 'Nieprawidłowy nagłówek CSV',
    'client_portal' => 'Portal klienta',
    'admin' => 'Administrator',
    'disabled' => 'Wyłączono',
    'show_archived_users' => 'Pokaż zarchiwizowanych użytkowników',
    'notes' => 'Notatki',
    'invoice_will_create' => 'Faktura zostanie utworzona',
    'invoices_will_create' => 'faktury zostaną utworzone',
    'failed_to_import' => 'The following records failed to import, they either already exist or are missing required fields.',
    'publishable_key' => 'Publishable Key',
    'secret_key' => 'Sekretny klucz',
    'missing_publishable_key' => 'Set your Stripe publishable key for an improved checkout process',
    'email_design' => 'Motyw email',
    'due_by' => 'Termin płatności :date',
    'enable_email_markup' => 'Aktywuj Markup',
    'enable_email_markup_help' => 'Make it easier for your clients to pay you by adding schema.org markup to your emails.',
    'template_help_title' => 'Pomoc dla Szablonów',
    'template_help_1' => 'Dostępne zmienne:',
    'email_design_id' => 'Motyw email',
    'email_design_help' => 'Spraw by Twoje emaile wyglądały profesjonalnie dzięki użyciu HTML.',
    'plain' => 'Zwykły',
    'light' => 'Jasny',
    'dark' => 'Ciemny',
    'industry_help' => 'Informacje używane w celach porównawczych przy obliczaniu statystyk firm podobnych rozmiarów i branż.',
    'subdomain_help' => 'Ustaw subdomenę lub wyświetl fakturę na swojej stronie.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the invoice number.',
    'quote_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the quote number.',
    'custom_client_fields_helps' => 'Dodaj pole przy tworzeniu klienta i opcjonalnie wyświetlaj jego etykietę oraz wartość w pliku PDF.',
    'custom_account_fields_helps' => 'Add a label and value to the company details section of the PDF.',
    'custom_invoice_fields_helps' => 'Dodaj pole przy tworzeniu faktury i opcjonalnie wyświetlaj jego etykietę oraz wartość w pliku PDF.',
    'custom_invoice_charges_helps' => 'Add a field when creating an invoice and include the charge in the invoice subtotals.',
    'token_expired' => 'Validation token was expired. Please try again.',
    'invoice_link' => 'Link faktury',
    'button_confirmation_message' => 'Kliknij, aby potwierdzić swój adres email.',
    'confirm' => 'Potwierdź',
    'email_preferences' => 'Preferencje email',
    'created_invoices' => 'Successfully created :count invoice(s)',
    'next_invoice_number' => 'Następny numer faktury jest :number.',
    'next_quote_number' => 'Następny numer oferty jest :number.',
    'days_before' => 'dni przed',
    'days_after' => 'dni po',
    'field_due_date' => 'termin',
    'field_invoice_date' => 'data faktury',
    'schedule' => 'Zaplanuj',
    'email_designs' => 'Motyw email',
    'assigned_when_sent' => 'Przypisany po wysłaniu',
    'white_label_purchase_link' => 'Purchase a white label license',
    'expense' => 'Wydatek',
    'expenses' => 'Wydatki',
    'new_expense' => 'Dodaj wydatek',
    'enter_expense' => 'Dodaj wydatek',
    'vendors' => 'Dostawcy',
    'new_vendor' => 'Nowy dostawca',
    'payment_terms_net' => 'Net',
    'vendor' => 'Dostawca',
    'edit_vendor' => 'Edytuj dostawcę',
    'archive_vendor' => 'Archiwizuj dostawcę',
    'delete_vendor' => 'Usuń dostawcę',
    'view_vendor' => 'Zobacz dostawcę',
    'deleted_expense' => 'Wydatki zostały usunięte',
    'archived_expense' => 'Wydatki zostały zarchiwizowane',
    'deleted_expenses' => 'Wydatki zostały usunięte',
    'archived_expenses' => 'Wydatki zostały zarchiwizowane',
    'expense_amount' => 'Wartość wydatków',
    'expense_balance' => 'Saldo wydatków',
    'expense_date' => 'Data obciążenia',
    'expense_should_be_invoiced' => 'Utwórz fakturę dla poniesionego kosztu?',
    'public_notes' => 'Notatki publiczne',
    'invoice_amount' => 'Kwota faktury',
    'exchange_rate' => 'Kurs wymiany',
    'yes' => 'Tak',
    'no' => 'Nie',
    'should_be_invoiced' => 'Utwórz fakturę',
    'view_expense' => 'Zobacz wydatek # :expense',
    'edit_expense' => 'Edytuj wydatek',
    'archive_expense' => 'Archiwizuj wydatek',
    'delete_expense' => 'Usuń wydatek',
    'view_expense_num' => 'Wydatek # :expense',
    'updated_expense' => 'Wydatek został zaktualizowany',
    'created_expense' => 'Wydatek został utworzony',
    'enter_expense' => 'Dodaj wydatek',
    'view' => 'Podgląd',
    'restore_expense' => 'Przywróć wydatek',
    'invoice_expense' => 'Faktura na wydatek',
    'expense_error_multiple_clients' => 'Wydatek nie może należeć do innych klientów',
    'expense_error_invoiced' => 'Faktura do wydatku została już utworzona',
    'convert_currency' => 'Konwertuj walutę',
    'num_days' => 'Liczba dni',
    'create_payment_term' => 'Utwórz warunki płatności',
    'edit_payment_terms' => 'Edytuj warunki płatności',
    'edit_payment_term' => 'Edytuj warunki płatności',
    'archive_payment_term' => 'Zarchiwizuj warunki płatności',
    'recurring_due_dates' => 'Terminy faktur okresowych',
    'recurring_due_date_help' => '<p>Automatycznie ustawia termin faktury.</p>
        <p>Invoices on a monthly or yearly cycle set to be due on or before the day they are created will be due the next month. Invoices set to be due on the 29th or 30th in months that don\'t have that day will be due the last day of the month.</p>
        <p>Invoices on a weekly cycle set to be due on the day of the week they are created will be due the next week.</p>
        <p>Na przykład:</p>
        <ul>
          <li>Dziś jest 15. dzień miesiąca, ustawiony termin faktury to 1. dzień miesiąca. Terminem płatności będzie więc 1. dzień następnego miesiąca</li>
          <li>Dziś jest 15. dzień miesiąca, ustawiony termin faktury to ostatni dzień miesiąca. Terminem płatności będzie więc ostatni dzień bieżącego miesiąca.
</li>
          <li>Dziś jest 15. dzień miesiąca, ustawiony termin faktury to 15. dzień miesiąca. Terminem płatności będzie więc 15. dzień <strong>następnego</strong> miesiąca.
</li>
          <li>Dziś jest piątek, ustawiony termin faktury to "najbliższy piątek". Terminem płatności nie będzie dzień dzisiejszy lecz piątek za tydzień.
</li>
        </ul>',
    'due' => 'Opłata',
    'next_due_on' => 'Następna opłata: :date',
    'use_client_terms' => 'Użyj warunków klienta',
    'day_of_month' => ':ordinal day of month',
    'last_day_of_month' => 'Ostatni dzień miesiąca',
    'day_of_week_after' => ':ordinal :day after',
    'sunday' => 'Niedziela',
    'monday' => 'Poniedziałek',
    'tuesday' => 'Wtorek',
    'wednesday' => 'Środa',
    'thursday' => 'Czwartek',
    'friday' => 'Piątek',
    'saturday' => 'Sobota',
    'header_font_id' => 'Czcionka nagłówka',
    'body_font_id' => 'Czcionka',
    'color_font_help' => 'Notatka: Podstawowe kolory i czcionki są wykorzystywane na portalu klienta i w niestandardowych szablonach email-owych.',
    'live_preview' => 'Podgląd',
    'invalid_mail_config' => 'E-mail nie został wysłany. Sprawdź czy ustawienia mailowe są poprawne.',
    'invoice_message_button' => 'Aby wyświetlić fakturę za :amount, kliknij przycisk poniżej.',
    'quote_message_button' => 'Aby wyświetlić swoją ofertę na :amount, kliknij przycisk poniżej.',
    'payment_message_button' => 'Dziekuję za wpłatę :amount.',
    'payment_type_direct_debit' => 'Polecenie zapłaty',
    'bank_accounts' => 'Karty kredytowe i banki',
    'add_bank_account' => 'Dodaj konto bankowe',
    'setup_account' => 'Ustawienia konta',
    'import_expenses' => 'Koszty importu',
    'bank_id' => 'Bank',
    'integration_type' => 'Rodzaj integracji',
    'updated_bank_account' => 'Konto bankowe zostało zaktualizowane',
    'edit_bank_account' => 'Edytuj konto bankowe',
    'archive_bank_account' => 'Archiwizuj konto bankowe',
    'archived_bank_account' => 'Konto bankowe zostało zarchiwizowane.',
    'created_bank_account' => 'Konto bankowe zostało utworzone',
    'validate_bank_account' => 'Zatwierdź konto bankowe',
    'bank_password_help' => 'Notatka: Twoje hasło przesyłane jest bezpiecznie i nie będzie przechowywane na naszych serwerach.',
    'bank_password_warning' => 'Ostrzeżenie: Twoje hasło może być wysłane w postaci zwykłego tekstu, rozwaź aktywację protokołu HTTPS.',
    'username' => 'Użytkownik',
    'account_number' => 'Numer konta',
    'account_name' => 'Nazwa konta',
    'bank_account_error' => 'Nie udało się pobrać informacji z konta, proszę sprawdzić swój login i hasło.',
    'status_approved' => 'Zatwierdzono',
    'quote_settings' => 'Ustawienia oferty',
    'auto_convert_quote' => 'Automatycznie konwertuj',
    'auto_convert_quote_help' => 'Utwórz automatycznie fakturę z oferty zaakceptowanej przez klienta.',
    'validate' => 'Zatwierdź',
    'info' => 'Informacja',
    'imported_expenses' => 'Successfully created :count_vendors vendor(s) and :count_expenses expense(s)',
    'iframe_url_help3' => 'Note: if you plan on accepting credit cards details we strongly recommend enabling HTTPS on your site.',
    'expense_error_multiple_currencies' => 'The expenses can\'t have different currencies.',
    'expense_error_mismatch_currencies' => 'The client\'s currency does not match the expense currency.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Nagłówek/Stopka',
    'first_page' => 'Pierwsza strona',
    'all_pages' => 'Wszystkie strony',
    'last_page' => 'Ostatnia strona',
    'all_pages_header' => 'Pokaż nagłówek na',
    'all_pages_footer' => 'Pokaż stopkę na',
    'invoice_currency' => 'Waluta faktury',
    'enable_https' => 'Zalecamy korzystanie z protokołu HTTPS do przetwarzania online danych kart kredytowych.',
    'quote_issued_to' => 'Oferta wydana do',
    'show_currency_code' => 'Kod waluty',
    'free_year_message' => 'Twoje konto zostało podniesione do wersji pro na rok bez dodatkowego kosztu.',
    'trial_message' => 'Twoje konto otrzyma bezpłatny dwutygodniowy okres próbny naszego pro planu.',
    'trial_footer' => 'Twoja wersja próbna planu pro trwa jeszcze :count dni, przedłuż tutaj :link.',
    'trial_footer_last_day' => 'To ostatni dzień twojego bezpłatnego okresu próbnego, aby zaktualizować kliknij: :link.',
    'trial_call_to_action' => 'Rozpocznij darmowy okres próbny',
    'trial_success' => 'Darmowy okres próbny został włączony',
    'overdue' => 'Zaległość',


    'white_label_text' => 'Kup roczną licencję white label za $:price, aby usunąć wzmianki o Invoice Ninja z faktur i portalu klienta.',
    'user_email_footer' => 'Aby dostosować ustawienia powiadomień email, zobacz :link',
    'reset_password_footer' => 'Prosimy o kontakt, jeśli nie wysłałeś prośby o zresetowanie hasła: :email',
    'limit_users' => 'Sorry, this will exceed the limit of :limit users',
    'more_designs_self_host_header' => 'Kup 6 szablonów faktur za jedyne $:price',
    'old_browser' => 'Użyj :link',
    'newer_browser' => 'nowsza przeglądarka',
    'white_label_custom_css' => ':link for $:price to enable custom styling and help support our project.',
    'bank_accounts_help' => 'Połącz się automatycznie z kontem bankowym, aby pobrać wydatki i stworzyć dostawców. Obsługa American Express i :link.',
    'us_banks' => '400+ Amerykańskich banków',

    'pro_plan_remove_logo' => ':link to remove the Invoice Ninja logo by joining the Pro Plan',
    'pro_plan_remove_logo_link' => 'Kliknij tutaj',
    'invitation_status_sent' => 'Wysłane',
    'invitation_status_opened' => 'Otwarte',
    'invitation_status_viewed' => 'Wyświetlono',
    'email_error_inactive_client' => 'E-maile nie mogą być wysyłane do klientów nieaktywnych',
    'email_error_inactive_contact' => 'E-mail nie może zostać wysłany do nieaktywnych kontaktów',
    'email_error_inactive_invoice' => 'E-mail nie może zostać wysłany do nieaktywnych faktur',
    'email_error_inactive_proposal' => 'E-mail nie może zostać wysłany do nieaktywnych ofert',
    'email_error_user_unregistered' => 'Proszę zarejestrować swoje konto, aby wysyłać e-maile',
    'email_error_user_unconfirmed' => 'Proszę potwierdzić swoje konto do wysyłania e-maili',
    'email_error_invalid_contact_email' => 'Nieprawidłowy e-mail kontaktowy',

    'navigation' => 'Nawigacja',
    'list_invoices' => 'Lista faktur',
    'list_clients' => 'Lista klientów',
    'list_quotes' => 'Lista ofert',
    'list_tasks' => 'Lista zadań',
    'list_expenses' => 'Lista wydatków',
    'list_recurring_invoices' => 'Lista faktur okresowych',
    'list_payments' => 'Lista wpłat',
    'list_credits' => 'Lista kredytów',
    'tax_name' => 'Nazwa podatku',
    'report_settings' => 'Ustawienia raportu',
    'search_hotkey' => 'skrót to /',

    'new_user' => 'Nowy użytkownik',
    'new_product' => 'Nowy produkt',
    'new_tax_rate' => 'Nowa stawka podatkowa',
    'invoiced_amount' => 'Fakturowana kwota',
    'invoice_item_fields' => 'Invoice Item Fields',
    'custom_invoice_item_fields_help' => 'Add a field when creating an invoice item and display the label and value on the PDF.',
    'recurring_invoice_number' => 'Numer cykliczny',
    'recurring_invoice_number_prefix_help' => 'Dodaj własny prefix do numeru faktury okresowej. ',

    // Client Passwords
    'enable_portal_password' => 'Faktury chronione hasłem',
    'enable_portal_password_help' => 'Zezwala na utworzenie haseł dla każdego kontaktu. Jeśli hasło zostanie ustanowione, użytkownik będzie musiał podać hasło, aby przeglądać faktury.',
    'send_portal_password' => 'Wygeneruj automatycznie',
    'send_portal_password_help' => 'Wygeneruje hasło automatycznie, jeśli nie zostanie ono wpisane. Klient otrzyma je razem z pierwszą fakturą.',

    'expired' => 'Wygasło',
    'invalid_card_number' => 'Numer karty kredytowej jest nieprawidłowy.',
    'invalid_expiry' => 'Data ważności jest nieprawidłowa.',
    'invalid_cvv' => 'Kod CVV jest nieprawidłowy.',
    'cost' => 'Koszt',
    'create_invoice_for_sample' => 'Notatka: aby zobaczyć podgląd, utwórz fakturę.',

    // User Permissions
    'owner' => 'Właściciel',
    'administrator' => 'Administrator',
    'administrator_help' => 'Zezwól użytkownikowi na zarządzanie użytkownikami, edytowanie ustawień oraz wszystkich danych.',
    'user_create_all' => 'Tworzenie klientów, faktury, itp.',
    'user_view_all' => 'Przeglądanie danych wszystkich klientów, wszystkich faktury, itp.',
    'user_edit_all' => 'Edytowanie wszystkich klientów, wszystkich faktur, itp.',
    'gateway_help_20' => ':link to sign up for Sage Pay.',
    'gateway_help_21' => ':link to sign up for Sage Pay.',
    'partial_due' => 'Zaliczka',
    'restore_vendor' => 'Przywróć dostawcę',
    'restored_vendor' => 'Dostawca został przywrócony',
    'restored_expense' => 'Wydatek został przywrócony',
    'permissions' => 'Uprawnienia',
    'create_all_help' => 'Zezwól użytkownikowi na dodawanie i edytowanie danych',
    'view_all_help' => 'Zezwól użytkownikowi na przeglądanie danych innych użytkowników.',
    'edit_all_help' => 'Zezwól użytkownikowi na edytowanie danych innych użytkowników.',
    'view_payment' => 'Zobacz wpłatę',

    'january' => 'Styczeń',
    'february' => 'Luty',
    'march' => 'Marzec',
    'april' => 'Kwiecień',
    'may' => 'Maj',
    'june' => 'Czerwiec',
    'july' => 'Lipiec',
    'august' => 'Sierpień',
    'september' => 'Wrzesień',
    'october' => 'Październik',
    'november' => 'Listopad',
    'december' => 'Grudzień',

    // Documents
    'documents_header' => 'Dokumenty:',
    'email_documents_header' => 'Dokumenty:',
    'email_documents_example_1' => 'Widgets Receipt.pdf',
    'email_documents_example_2' => 'Final Deliverable.zip',
    'quote_documents' => 'Dokumenty oferty',
    'invoice_documents' => 'Dokumenty Faktury',
    'expense_documents' => 'Dokumenty wydatku',
    'invoice_embed_documents' => 'Załączniki',
    'invoice_embed_documents_help' => 'Wstaw do faktury załączniki graficzne.',
    'document_email_attachment' => 'Załącz dokumenty',
    'ubl_email_attachment' => 'Dodaj UBL',
    'download_documents' => 'Ściągnij dokumenty (:size)',
    'documents_from_expenses' => 'From Expenses:',
    'dropzone_default_message' => 'Upuść pliki lub kliknij, aby przesłać',
    'dropzone_default_message_disabled' => 'Upload wyłączony',
    'dropzone_fallback_message' => 'Your browser does not support drag\'n\'drop file uploads.',
    'dropzone_fallback_text' => 'Please use the fallback form below to upload your files like in the olden days.',
    'dropzone_file_too_big' => 'Plik jest zbyt duży ({{filesize}}MiB). Max rozmiar pliku: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Nie możesz przesłać plików tego typu.',
    'dropzone_response_error' => 'Serwer zwraca {{statusCode}} kod.',
    'dropzone_cancel_upload' => 'Anuluj przesyłanie',
    'dropzone_cancel_upload_confirmation' => 'Czy na pewno chcesz anulować przesyłanie pliku?',
    'dropzone_remove_file' => 'Usuń plik',
    'documents' => 'Dokumenty',
    'document_date' => 'Data dokumentu',
    'document_size' => 'Rozmiar',

    'enable_client_portal' => 'Portal Klienta',
    'enable_client_portal_help' => 'Pokaż/ukryj portal klienta.',
    'enable_client_portal_dashboard' => 'Pulpit',
    'enable_client_portal_dashboard_help' => 'Pokaż/ukryj pulpit w panelu klienta.',

    // Plans
    'account_management' => 'Zarządzanie kontem',
    'plan_status' => 'Plan Status',

    'plan_upgrade' => 'Aktualizuj',
    'plan_change' => 'Zmień plan',
    'pending_change_to' => 'Zmienia się na',
    'plan_changes_to' => ':plan on :date',
    'plan_term_changes_to' => ':plan (:term) on :date',
    'cancel_plan_change' => 'Anuluj zmianę',
    'plan' => 'Plan',
    'expires' => 'Wygasa',
    'renews' => 'Odnawia',
    'plan_expired' => ':plan Plan Expired',
    'trial_expired' => ':plan Plan Trial Ended',
    'never' => 'Nigdy',
    'plan_free' => 'Darmowy',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (White labeled)',
    'plan_free_self_hosted' => 'Self Hosted (Free)',
    'plan_trial' => 'Trial',
    'plan_term' => 'Term',
    'plan_term_monthly' => 'Miesięcznie',
    'plan_term_yearly' => 'Rocznie',
    'plan_term_month' => 'Miesiąc',
    'plan_term_year' => 'Rok',
    'plan_price_monthly' => '$:price/miesiąc',
    'plan_price_yearly' => '$:price/rok',
    'updated_plan' => 'Ustawienia planu zaktualizowane',
    'plan_paid' => 'Termin rozpoczął',
    'plan_started' => 'Plan rozpoczął',
    'plan_expires' => 'Plan Wygasa',

    'white_label_button' => 'Biała etykieta',

    'pro_plan_year_description' => 'One year enrollment in the Invoice Ninja Pro Plan.',
    'pro_plan_month_description' => 'One month enrollment in the Invoice Ninja Pro Plan.',
    'enterprise_plan_product' => 'Plan Enterprise',
    'enterprise_plan_year_description' => 'One year enrollment in the Invoice Ninja Enterprise Plan.',
    'enterprise_plan_month_description' => 'One month enrollment in the Invoice Ninja Enterprise Plan.',
    'plan_credit_product' => 'Kredyt',
    'plan_credit_description' => 'Kredyt za niewykorzystany czas',
    'plan_pending_monthly' => 'Will switch to monthly on :date',
    'plan_refunded' => 'Zwrot został wystawiony.',

    'live_preview' => 'Podgląd',
    'page_size' => 'Rozmiar strony',
    'live_preview_disabled' => 'Podgląd obrazu na żywo został wyłączony w celu wsparcia wybranej czcionki',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Preview',
    'list_vendors' => 'List Vendors',
    'add_users_not_supported' => 'Upgrade to the Enterprise plan to add additional users to your account.',
    'enterprise_plan_features' => 'Plan Enterprise dodaje wsparcie dla wielu użytkowników oraz obsługę załączników. Zobacz :link, by poznać wszystkie funkcjonalności.',
    'return_to_app' => 'Powrót do aplikacji',


    // Payment updates
    'refund_payment' => 'Zwrot płatności',
    'refund_max' => 'Max:',
    'refund' => 'Zwrot',
    'are_you_sure_refund' => 'Zwrot wybranych płatności',
    'status_pending' => 'Oczekuję',
    'status_completed' => 'Zakończone',
    'status_failed' => 'Niepowodzenie',
    'status_partially_refunded' => 'Częściowo zwrócone',
    'status_partially_refunded_amount' => 'zwrócone',
    'status_refunded' => 'Zwrócone',
    'status_voided' => 'Anulowane',
    'refunded_payment' => 'Zwrócono płatność',
    'activity_39' => ':user anulował płatność na :payment_amount nr. :payment ',
    'activity_40' => ':user refunded :adjustment of a :payment_amount payment :payment',
    'card_expiration' => 'Wyd:&nbsp:wygasa',

    'card_creditcardother' => 'Nieznany',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept US bank transfers',
    'stripe_ach_help' => 'ACH support must also be enabled in :link.',
    'ach_disabled' => 'Inny dostawca płatności kartami debetowymi został już skonfigurowany.',

    'plaid' => 'Plaid',
    'client_id' => 'Numer klienta',
    'secret' => 'Tajny',
    'public_key' => 'Klucz publiczny',
    'plaid_optional' => '(opcjonalne)',
    'plaid_environment_help' => 'When a Stripe test key is given, Plaid\'s development environment (tartan) will be used.',
    'other_providers' => 'Inni dostawcy',
    'country_not_supported' => 'Dany kraj nie jest obsługiwany.',
    'invalid_routing_number' => 'Numer rozliczeniowy banku jest niepoprawny.',
    'invalid_account_number' => 'Numer konta jest nieprawidłowy',
    'account_number_mismatch' => 'Numery konta nie pasują.',
    'missing_account_holder_type' => 'Proszę wybrać osobiste lub firmowe konto.',
    'missing_account_holder_name' => 'Wprowadź nazwę właściciela konta',
    'routing_number' => 'Numer rozliczeniowy banku',
    'confirm_account_number' => 'Potwierdź numer konta',
    'individual_account' => 'Konto osobiste',
    'company_account' => 'Konto firmowe',
    'account_holder_name' => 'Nazwa właściciela konta',
    'add_account' => 'Dodaj konto',
    'payment_methods' => 'Formy płatności',
    'complete_verification' => 'Dokończ weryfikację',
    'verification_amount1' => '1 Kwota',
    'verification_amount2' => '2 Kwota',
    'payment_method_verified' => 'Veryfikacja zakończona pomyślnie',
    'verification_failed' => 'Nieudana weryfikacja',
    'remove_payment_method' => 'Usuń formę płatności',
    'confirm_remove_payment_method' => 'Czy na pewno chcesz usunąć tą formę płatności?',
    'remove' => 'Usuń',
    'payment_method_removed' => 'Forma płatności usunięta',
    'bank_account_verification_help' => 'Wykonaliśmy dwa przelewy na Twoje konto z tytułem "Verification" lub "Weryfikacja". Środki powinny pojawić się na Twoim koncie w ciągu 1-2 dni roboczy. Wprowadź poniżej ich kwoty.',
    'bank_account_verification_next_steps' => 'Wykonaliśmy dwa przelewy na Twoje konto z tytułem "Verification" lub "Weryfikacja". Środki powinny pojawić się na Twoim koncie w ciągu 1-2 dni roboczy.
Gdy przelewy zostaną zaksięgowane na Twoim koncie, wróć do tej strony i kliknij "Dokończ weryfikację" obok właściwego konta.',
    'unknown_bank' => 'Nieznany bank',
    'ach_verification_delay_help' => 'Konto będzie aktywne, po dokończeniu weryfikacji. Weryfikacja trwa 1-2 dni robocze.',
    'add_credit_card' => 'Dodaj kartę kredytową',
    'payment_method_added' => 'Dodano formę płatności',
    'use_for_auto_bill' => 'Użyj do płatności automatycznych',
    'used_for_auto_bill' => 'Metoda płatności automatycznych',
    'payment_method_set_as_default' => 'Ustaw metodą płatności automatycznych.',
    'activity_41' => 'płatność :payment_amount (:payment) nieudana',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Musisz :link.',
    'stripe_webhook_help_link_text' => 'dodaj ten URL jako endpoint w Stripe',
    'gocardless_webhook_help_link_text' => 'add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'Wystąpił problem w trakcie dodawania metody płatności. Spróbuj ponownie później.',
    'notification_invoice_payment_failed_subject' => 'Płatność dla faktury :invoice nie powiodła się',
    'notification_invoice_payment_failed' => 'Płatność wykonana przez klienta :client za fakturę :invoice zakończona niepowodzeniem. Płatność została oznaczona jako nieudana, a środki  :amount zostały dopisane do salda klienta.',
    'link_with_plaid' => 'Połącz konto z Plaid',
    'link_manually' => 'Połącz ręcznie',
    'secured_by_plaid' => 'Zabezpieczane przez Plaid',
    'plaid_linked_status' => 'Twoje konto bankowe w :bank',
    'add_payment_method' => 'Dodaj formę płatności',
    'account_holder_type' => 'Typ konta właściciela',
    'ach_authorization' => 'I authorize :company to use my bank account for future payments and, if necessary, electronically credit my account to correct erroneous debits. I understand that I may cancel this authorization at any time by removing the payment method or by contacting :email.',
    'ach_authorization_required' => 'Musisz wyrazić zgodę na transakcje ACH.',
    'off' => 'Wyłaczono',
    'opt_in' => 'Zgoda',
    'opt_out' => 'Rezygnacja',
    'always' => 'Zawsze',
    'opted_out' => 'Opted out',
    'opted_in' => 'Opted in',
    'manage_auto_bill' => 'Zarządzaj automatycznymi płatnościami',
    'enabled' => 'Aktywny',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Aktywuj płatności PayPal za pośrednictwem BrainTree',
    'braintree_paypal_disabled_help' => 'PayPal jako dostawca przetwarza płatności z PayPal',
    'braintree_paypal_help' => 'Musisz także :link.',
    'braintree_paypal_help_link_text' => 'połącz PayPal ze swoim kontem BrainTree',
    'token_billing_braintree_paypal' => 'Zapisz dane płatności',
    'add_paypal_account' => 'Dodaj konto PayPal',


    'no_payment_method_specified' => 'Nie wybrano formy płatności',
    'chart_type' => 'Typ wykresu',
    'format' => 'Format',
    'import_ofx' => 'Importuj OFX',
    'ofx_file' => 'Plik OFX',
    'ofx_parse_failed' => 'Przetwarzania pliku OFX nieudane',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Zarejestruj się w WePay',
    'use_another_provider' => 'Użyj innego dostawcy',
    'company_name' => 'Nazwa firmy',
    'wepay_company_name_help' => 'To pojawi się na wyciągu z karty kredytowej klienta.',
    'wepay_description_help' => 'Cel konta',
    'wepay_tos_agree' => 'Zgadzam się z :link',
    'wepay_tos_link_text' => 'Warunki WePay',
    'resend_confirmation_email' => 'Wyślij ponownie email potwierdzający',
    'manage_account' => 'Zarządzanie kontem',
    'action_required' => 'Wymagane działanie',
    'finish_setup' => 'Zakończ konfigurację',
    'created_wepay_confirmation_required' => 'Proszę sprawdź swoją skrzynkę email i potwierdź adres email dla WePay.',
    'switch_to_wepay' => 'Przełącz na WePay',
    'switch' => 'Zmień',
    'restore_account_gateway' => 'Przywróć dostawcę płątności',
    'restored_account_gateway' => 'Przywracanie dostawcy płatności zakończone powodzeniem',
    'united_states' => 'Stany Zjednoczone',
    'canada' => 'Kanada',
    'accept_debit_cards' => 'Akceptuj karty debetowe',
    'debit_cards' => 'Karty debetowe',

    'warn_start_date_changed' => 'Nowa faktura zostanie wysłana w nowej dacie początkowej.',
    'warn_start_date_changed_not_sent' => 'Następna faktura zostanie stworzona w nowej dacie początkowej.',
    'original_start_date' => 'Pierwotna data początkowa',
    'new_start_date' => 'Nowa data początkowa',
    'security' => 'Bezpieczeństwo',
    'see_whats_new' => 'Zobacz co nowego w v:version',
    'wait_for_upload' => 'Poczekaj na zakończenie przesyłania dokumentu.',
    'upgrade_for_permissions' => 'Przejdź na plan Enterprise, aby zarządzać uprawnieniami.',
    'enable_second_tax_rate' => 'Określ <b>drugą stawkę podatkową</b>',
    'payment_file' => 'Plik płatności',
    'expense_file' => 'Plik wydatków',
    'product_file' => 'Plik produktu',
    'import_products' => 'Importuj produkty',
    'products_will_create' => 'produktów zostanie utworzonych',
    'product_key' => 'Produkt',
    'created_products' => 'Successfully created/updated :count product(s)',
    'export_help' => 'Użyj formatu JSON, jeśli planujesz zaimportować dane do Invoice Ninja.<br/> Taki plik zawiera dane klientów, produkty, faktury, oferty i płatności.',
    'selfhost_export_help' => '<br/>We recommend using mysqldump to create a full backup.',
    'JSON_file' => 'Plik JSON',

    'view_dashboard' => 'Zobacz Pulpit',
    'client_session_expired' => 'Sesja wygasła',
    'client_session_expired_message' => 'Twoja sesja wygasła. Proszę kliknij ponownie  w link, który znajduje się w Twojej skrzynce e-mail.',

    'auto_bill_notification' => 'This invoice will automatically be billed to your :payment_method on file on :due_date.',
    'auto_bill_payment_method_bank_transfer' => 'numer konta',
    'auto_bill_payment_method_credit_card' => 'karta kredytowa',
    'auto_bill_payment_method_paypal' => 'Konto PayPal',
    'auto_bill_notification_placeholder' => 'This invoice will automatically be billed to your credit card on file on the due date.',
    'payment_settings' => 'Ustawienia Płatności',

    'on_send_date' => 'W datę wysyłki',
    'on_due_date' => 'W termin płatności',
    'auto_bill_ach_date_help' => 'Obciążania typu ACH zawsze pobierane będą w ostatnim dniu terminu płatności.',
    'warn_change_auto_bill' => 'Due to NACHA rules, changes to this invoice may prevent ACH auto bill.',

    'bank_account' => 'Konto bankowe',
    'payment_processed_through_wepay' => 'Obciążenia typu ACH będą przetwarzane przez WePay.',
    'wepay_payment_tos_agree' => 'Zgadzam się z warunkami WePay :terms i :privacy_policy.',
    'privacy_policy' => 'Polityka prywatności',
    'wepay_payment_tos_agree_required' => 'Musisz zaakceptować warunki świadczenia usług oraz politykę prywatności WePay.',
    'ach_email_prompt' => 'Proszę wprowadź swój adres email:',
    'verification_pending' => 'Oczekiwanie na weryfikację',

    'update_font_cache' => 'Proszę odświeżyć stronę, aby zaktualizować cache fontów.',
    'more_options' => 'Więcej opcji',
    'credit_card' => 'Karta Kredytowa',
    'bank_transfer' => 'Przelew bankowy',
    'no_transaction_reference' => 'Nie otrzymaliśmy numeru referencyjnego płatności od dostawcy płatności.',
    'use_bank_on_file' => 'Use Bank on File',
    'auto_bill_email_message' => 'Ta faktura zostanie automatycznie opłacona w ostatnim dniu terminu zapłaty.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Dodano :date',
    'failed_remove_payment_method' => 'Nie udało się usunąć metody płatności',
    'gateway_exists' => 'Ten dostawca płatności już istnieje',
    'manual_entry' => 'Ręczny wpis',
    'start_of_week' => 'Pierwszy dzień tygodnia',

    // Frequencies
    'freq_inactive' => 'Nieaktywne',
    'freq_daily' => 'Codziennie',
    'freq_weekly' => 'Co tydzień',
    'freq_biweekly' => 'Co dwa tygodnie',
    'freq_two_weeks' => 'Co dwa tygodnie',
    'freq_four_weeks' => 'Co cztery tygodnie',
    'freq_monthly' => 'Co miesiąc',
    'freq_three_months' => 'Co trzy miesiące',
    'freq_four_months' => 'Four months',
    'freq_six_months' => 'Co sześć miesięcy',
    'freq_annually' => 'Co rok',
    'freq_two_years' => 'Dwa lata',

    // Payment types
    'payment_type_Apply Credit' => 'Zastosuj kredyt',
    'payment_type_Bank Transfer' => 'Przelew bankowy',
    'payment_type_Cash' => 'Gotówka',
    'payment_type_Debit' => 'Debet',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Visa Card',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Inna karta kredytowa',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Czek',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Księgowość i prawo',
    'industry_Advertising' => 'Reklama',
    'industry_Aerospace' => 'Przemysł kosmiczny',
    'industry_Agriculture' => 'Rolnictwo',
    'industry_Automotive' => 'Motoryzacja',
    'industry_Banking & Finance' => 'Bankowość i finanse',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Nadawanie',
    'industry_Business Services' => 'Usługi dla biznesu',
    'industry_Commodities & Chemicals' => 'Towary i chemikalia',
    'industry_Communications' => 'Komunikacja',
    'industry_Computers & Hightech' => 'Komputery i nowoczesne technologie',
    'industry_Defense' => 'Obrona',
    'industry_Energy' => 'Branża energetyczna',
    'industry_Entertainment' => 'Rozrywka',
    'industry_Government' => 'Jednostki państwowe i samorządowe',
    'industry_Healthcare & Life Sciences' => 'Ochrona zdrowia i nauki przyrodnicze',
    'industry_Insurance' => 'Ubezpieczenia',
    'industry_Manufacturing' => 'Przemysł wytwórczy',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit i szkolnictwo wyższe',
    'industry_Pharmaceuticals' => 'Farmacja',
    'industry_Professional Services & Consulting' => 'Usługi doradcze i konsulting',
    'industry_Real Estate' => 'Nieruchomości',
    'industry_Restaurant & Catering' => 'Restaurant & Catering',
    'industry_Retail & Wholesale' => 'Sprzedaż i hurtownie',
    'industry_Sports' => 'Sporty',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Podróże i dobra luksusowe',
    'industry_Other' => 'Inne',
    'industry_Photography' => 'Fotografia',

    // Countries
    'country_Afghanistan' => 'Afganistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarktyda',
    'country_Algeria' => 'Algieria',
    'country_American Samoa' => 'Samoa Amerykańskie',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua i Barbuda',
    'country_Azerbaijan' => 'Azerbejdżan',
    'country_Argentina' => 'Argentyna',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamy',
    'country_Bahrain' => 'Bahrajn',
    'country_Bangladesh' => 'Bangladesz',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgia',
    'country_Bermuda' => 'Bermudy',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Boliwia',
    'country_Bosnia and Herzegovina' => 'Bośnia i Hercegowina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Wyspa Bouveta',
    'country_Brazil' => 'Brazylia',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'Brytyjskie Terytorium Oceanu Indyjskiego',
    'country_Solomon Islands' => 'Wyspy Salomona',
    'country_Virgin Islands, British' => 'Brytyjskie Wyspy Dziewicze',
    'country_Brunei Darussalam' => 'Brunei',
    'country_Bulgaria' => 'Bułgaria',
    'country_Myanmar' => 'Mjanma/Birma',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Białoruś',
    'country_Cambodia' => 'Kambodża',
    'country_Cameroon' => 'Kamerun',
    'country_Canada' => 'Kanada',
    'country_Cape Verde' => 'Republika Zielonego Przylądka',
    'country_Cayman Islands' => 'Kajmany',
    'country_Central African Republic' => 'Republika Środkowoafrykańska',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Czad',
    'country_Chile' => 'Chile',
    'country_China' => 'Chiny',
    'country_Taiwan, Province of China' => 'Tajwan',
    'country_Christmas Island' => 'Wyspa Bożego Narodzenia',
    'country_Cocos (Keeling) Islands' => 'Wyspy Kokosowe',
    'country_Colombia' => 'Kolumbia',
    'country_Comoros' => 'Komory',
    'country_Mayotte' => 'Majotta',
    'country_Congo' => 'Kongo',
    'country_Congo, the Democratic Republic of the' => 'Kongo',
    'country_Cook Islands' => 'Wyspy Cooka',
    'country_Costa Rica' => 'Kostaryka',
    'country_Croatia' => 'Chorwacja',
    'country_Cuba' => 'Kuba',
    'country_Cyprus' => 'Cypr',
    'country_Czech Republic' => 'Czechy',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Dania',
    'country_Dominica' => 'Dominika',
    'country_Dominican Republic' => 'Dominikana',
    'country_Ecuador' => 'Ekwador',
    'country_El Salvador' => 'Salwador',
    'country_Equatorial Guinea' => 'Gwinea Równikowa',
    'country_Ethiopia' => 'Etiopia',
    'country_Eritrea' => 'Erytrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Wyspy Owcze',
    'country_Falkland Islands (Malvinas)' => 'Falklandy (Malwiny)',
    'country_South Georgia and the South Sandwich Islands' => 'Georgia Południowa i Sandwich Południowy',
    'country_Fiji' => 'Fidżi',
    'country_Finland' => 'Finlandia',
    'country_Åland Islands' => 'Wyspy Alandzkie',
    'country_France' => 'Francja',
    'country_French Guiana' => 'Gujana Francuska',
    'country_French Polynesia' => 'Polinezja Francuska',
    'country_French Southern Territories' => 'Francuskie Terytoria Południowe i Antarktyczne',
    'country_Djibouti' => 'Dżibuti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Gruzja',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestyna',
    'country_Germany' => 'Niemcy',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Grecja',
    'country_Greenland' => 'Grenlandia',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Gwadelupa',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Gwatemala',
    'country_Guinea' => 'Gwinea',
    'country_Guyana' => 'Gujana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Wyspy Heard i McDonalda',
    'country_Holy See (Vatican City State)' => 'Stolica Apostolska (miasto Watykan)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Węgry',
    'country_Iceland' => 'Islandia',
    'country_India' => 'Indie',
    'country_Indonesia' => 'Indonezja ',
    'country_Iran, Islamic Republic of' => 'Iran',
    'country_Iraq' => 'Irak',
    'country_Ireland' => 'Irlandia',
    'country_Israel' => 'Izrael',
    'country_Italy' => 'Włochy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamajka',
    'country_Japan' => 'Japonia',
    'country_Kazakhstan' => 'Kazachstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenia',
    'country_Korea, Democratic People\'s Republic of' => 'Korea Północna',
    'country_Korea, Republic of' => 'Korea Południowa',
    'country_Kuwait' => 'Kuwejt',
    'country_Kyrgyzstan' => 'Kirgistan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Liban',
    'country_Lesotho' => 'Lesoto',
    'country_Latvia' => 'Łotwa',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libia',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Litwa',
    'country_Luxembourg' => 'Luksemburg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagaskar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauretania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Meksyk',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Czarnogóra',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Holandia',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Nowa Zelandia',
    'country_Nicaragua' => 'Nikaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norwegia',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Wyspy Marshalla',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paragwaj',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Filipiny',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Polska',
    'country_Portugal' => 'Portugalia',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Katar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Rumunia',
    'country_Russian Federation' => 'Rosja',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Arabia Saudyjska',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seszele',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapur',
    'country_Slovakia' => 'Słowacja',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Słowenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Hiszpania',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Szwecja',
    'country_Switzerland' => 'Szwajcaria',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tadżikistan',
    'country_Thailand' => 'Tajlandia',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunezja',
    'country_Turkey' => 'Turcja',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraina',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia',
    'country_Egypt' => 'Egipt',
    'country_United Kingdom' => 'Wielka Brytania',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Wyspa Man',
    'country_Tanzania, United Republic of' => 'Tanzania',
    'country_United States' => 'Stany Zjednoczone',
    'country_Virgin Islands, U.S.' => 'Wyspy Dziewicze Stanów Zjednoczonych',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Urugwaj',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Wenezuela',
    'country_Wallis and Futuna' => 'Wallis i Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Jemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Brazylijska odmiana języka portugalskiego',
    'lang_Croatian' => 'Chorwacki',
    'lang_Czech' => 'Czeski',
    'lang_Danish' => 'Duński',
    'lang_Dutch' => 'Holenderski',
    'lang_English' => 'Angielski',
    'lang_French' => 'Francuski',
    'lang_French - Canada' => 'Francuski kanadyjski',
    'lang_German' => 'Niemiecki',
    'lang_Italian' => 'Włoski',
    'lang_Japanese' => 'Japoński',
    'lang_Lithuanian' => 'Litewski',
    'lang_Norwegian' => 'Norweski',
    'lang_Polish' => 'Polski',
    'lang_Spanish' => 'Hiszpański',
    'lang_Spanish - Spain' => 'Hiszpański (Hiszpania)',
    'lang_Swedish' => 'Szwedzki',
    'lang_Albanian' => 'Albański',
    'lang_Greek' => 'Grecki',
    'lang_English - United Kingdom' => 'Angielski - Wielka Brytania',
    'lang_English - Australia' => 'Angielski - Australia',
    'lang_Slovenian' => 'Slovenian',
    'lang_Finnish' => 'Finnish',
    'lang_Romanian' => 'Romanian',
    'lang_Turkish - Turkey' => 'Turkish - Turkey',
    'lang_Portuguese - Brazilian' => 'Portuguese - Brazilian',
    'lang_Portuguese - Portugal' => 'Portuguese - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbski',
    'lang_Bulgarian' => 'Bułgarski',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Księgowość i prawo',
    'industry_Advertising' => 'Reklama',
    'industry_Aerospace' => 'Przemysł kosmiczny',
    'industry_Agriculture' => 'Rolnictwo',
    'industry_Automotive' => 'Motoryzacja',
    'industry_Banking & Finance' => 'Bankowość i finanse',
    'industry_Biotechnology' => 'Biotechnologie',
    'industry_Broadcasting' => 'Nadawanie',
    'industry_Business Services' => 'Usługi dla biznesu',
    'industry_Commodities & Chemicals' => 'Towary i chemikalia',
    'industry_Communications' => 'Komunikacja',
    'industry_Computers & Hightech' => 'Komputery i nowoczesne technologie',
    'industry_Defense' => 'Obrona',
    'industry_Energy' => 'Branża energetyczna',
    'industry_Entertainment' => 'Rozrywka',
    'industry_Government' => 'Jednostki państwowe i samorządowe',
    'industry_Healthcare & Life Sciences' => 'Ochrona zdrowia i nauki przyrodnicze',
    'industry_Insurance' => 'Ubezpieczenia',
    'industry_Manufacturing' => 'Przemysł wytwórczy',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Nonprofit i szkolnictwo wyższe',
    'industry_Pharmaceuticals' => 'Farmacja',
    'industry_Professional Services & Consulting' => 'Usługi doradcze i konsulting',
    'industry_Real Estate' => 'Nieruchomości',
    'industry_Retail & Wholesale' => 'Sprzedaż i hurtownie',
    'industry_Sports' => 'Sporty',
    'industry_Transportation' => 'Transport',
    'industry_Travel & Luxury' => 'Podróże i dobra luksusowe',
    'industry_Other' => 'Inne',
    'industry_Photography' => 'Fotografia',

    'view_client_portal' => 'Zobacz portal klienta',
    'view_portal' => 'Zobacz portal',
    'vendor_contacts' => 'Dane kontaktowe dostawców',
    'all' => 'Wszystko',
    'selected' => 'Wybranych',
    'category' => 'Kategoria',
    'categories' => 'Kategorie',
    'new_expense_category' => 'Nowa kategoria wydatków',
    'edit_category' => 'Edycja kategorii',
    'archive_expense_category' => 'Zarchiwizuj kategorię',
    'expense_categories' => 'Kategorie wydatków',
    'list_expense_categories' => 'Lista kategorii wydatków',
    'updated_expense_category' => 'Kategoria wydatków została zaktualizowana',
    'created_expense_category' => 'Kategoria wydatków została utworzona',
    'archived_expense_category' => 'Kategoria wydatków została zarchiwizowana',
    'archived_expense_categories' => 'Zarchiwizowana :count kategorii wydatków',
    'restore_expense_category' => 'Przywróć kategorię wydatków',
    'restored_expense_category' => 'Przywrócono kategorię wydatków',
    'apply_taxes' => 'Zastosuj podatki',
    'min_to_max_users' => 'od :min do :max użytkowników',
    'max_users_reached' => 'Maksymalna liczba użytkowników została osiągnięta.',
    'buy_now_buttons' => 'Przyciski Kup Teraz',
    'landing_page' => 'Strona początkowa',
    'payment_type' => 'Typ płatności',
    'form' => 'Formularz',
    'link' => 'Link',
    'fields' => 'Pola',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Uwaga: klient i faktury zostaną stworzona nawet jeśli transakcja nie zostanie dokończona.',
    'buy_now_buttons_disabled' => 'Ta funkcja wymaga utworzonego produktu i skonfigurowanego dostawcy płatności.',
    'enable_buy_now_buttons_help' => 'Włącz wsparcie dla przycisków Kup Teraz.',
    'changes_take_effect_immediately' => 'Uwaga: te zmiany widoczne są od razu.',
    'wepay_account_description' => 'Dostawca płatności dla Invoice Ninja',
    'payment_error_code' => 'Wystąpił błąd w trakcie przetwarzania twojej płatności [:code]. Proszę spróbować ponownie później.',
    'standard_fees_apply' => 'Opłaty: 2,9%/1,2% [Karta Kredytowa/Przelew] + $0.30 za udaną transakcję.',
    'limit_import_rows' => 'Dane powinny być importowane w partiach po :count linii lub mniej',
    'error_title' => 'Coś poszło nie tak',
    'error_contact_text' => 'Jeśli chciałbyś nam pomóc, skontaktuj się z nami: :mailaddress',
    'no_undo' => 'Ostrzeżenie: ta operacja nie może być cofnięta.',
    'no_contact_selected' => 'Wybierz kontakt',
    'no_client_selected' => 'Wybierz klienta',

    'gateway_config_error' => 'Pomocna może być zmiana hasła lub wygenerowanie nowego klucza API.',
    'payment_type_on_file' => ':type pliku',
    'invoice_for_client' => 'Faktura :invoice dla :client',
    'intent_not_found' => 'Przepraszam, ale nie jestem pewny o co pytasz.',
    'intent_not_supported' => 'Przepraszam, nie mogę tego zrobić.',
    'client_not_found' => 'Nie byłem w stanie znaleźć klienta',
    'not_allowed' => 'Przepraszam, nie masz wymaganych uprawnień',
    'bot_emailed_invoice' => 'Twoja faktura została wysłana.',
    'bot_emailed_notify_viewed' => 'Wyślę email po wyświetleniu tego.',
    'bot_emailed_notify_paid' => 'Wyślę email gdy zostanie to opłacone.',
    'add_product_to_invoice' => 'Dodaj 1 :product',
    'not_authorized' => 'Nie jesteś autoryzowany',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'Dziękuję! Wysłaliśmy email z kodem bezpieczeństwa.',
    'bot_welcome' => 'Gotowe, twoje konto zostało zweryfikowane.<br/>',
    'email_not_found' => 'Nie znalazłem konta dla adres email: email',
    'invalid_code' => 'Kod nie jest poprawny',
    'security_code_email_subject' => 'Kod bezpieczeństwa dla Invoice Ninja Bot',
    'security_code_email_line1' => 'This is your Invoice Ninja Bot security code.',
    'security_code_email_line2' => 'Uwaga: to wygaśnie za 10 minut.',
    'bot_help_message' => 'I currently support:<br/>• Create\update\email an invoice<br/>• List products<br/>For example:<br/><i>invoice bob for 2 tickets, set the due date to next thursday and the discount to 10 percent</i>',
    'list_products' => 'Lista produktów',

    'include_item_taxes_inline' => 'Wyświetlaj <b>sumę podatków w podsumowaniu</b>',
    'created_quotes' => 'Utworzono :count ofert(y).',
    'limited_gateways' => 'Uwaga: wspieramy tylko jednego dostawcę płatności kartami kredytowany na firmę',

    'warning' => 'Ostrzeżenie',
    'self-update' => 'Aktualizacja',
    'update_invoiceninja_title' => 'Zaktualizuj Invoice Ninja',
    'update_invoiceninja_warning' => 'Przed przejściem na nową wersję Invoice Ninja stwórz kopię bezpieczeństwa swojej bazy danych i plików.',
    'update_invoiceninja_available' => 'Nowa wersja Invoice Ninja jest dostępna.',
    'update_invoiceninja_unavailable' => 'Nowa wersja Invoice Ninja nie jest dostępna.',
    'update_invoiceninja_instructions' => 'Please install the new version <strong>:version</strong> by clicking the <em>Update now</em> button below. Afterwards you\'ll be redirected to the dashboard.',
    'update_invoiceninja_update_start' => 'Aktualizuj teraz',
    'update_invoiceninja_download_start' => 'Pobierz :version',
    'create_new' => 'Dodaj nowy/nową',

    'toggle_navigation' => 'Przełącz nawigację',
    'toggle_history' => 'Przełącz historię',
    'unassigned' => 'Nieprzypisano',
    'task' => 'Zadanie',
    'contact_name' => 'Nazwa kontaktu',
    'city_state_postal' => 'Miasto/województwo/kod pocztowy',
    'custom_field' => 'Dostosowane pole',
    'account_fields' => 'Pola firmy',
    'facebook_and_twitter' => 'Facebook i Twitter',
    'facebook_and_twitter_help' => 'Śledź nas aby pomóc wspierać nas projekt',
    'reseller_text' => 'Note: the white-label license is intended for personal use, please email us at :email if you\'d like to resell the app.',
    'unnamed_client' => 'Klient bez nazwy',

    'day' => 'Dzień',
    'week' => 'Tydzień',
    'month' => 'Miesiąc',
    'inactive_logout' => 'Nastąpiło wylogowaniu z powodu braku aktywności',
    'reports' => 'Raporty',
    'total_profit' => 'Całkowity zysk',
    'total_expenses' => 'Całkowite wydatki',
    'quote_to' => 'Oferta do',

    // Limits
    'limit' => 'Limit',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Bez limitu',
    'set_limits' => 'Ustaw limity dla :gateway_type',
    'enable_min' => 'Aktywuj min',
    'enable_max' => 'Aktywuj max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Ta faktura nie spełnia limitów dla wybranego rodzaju płatności.',

    'date_range' => 'Zakres czasowy',
    'raw' => 'Nieprzetworzony',
    'raw_html' => 'Nieprzetworzony kod HTML',
    'update' => 'Aktualizuj',
    'invoice_fields_help' => 'Przenoś pola, aby zmienić ich kolejność i położenie',
    'new_category' => 'Nowa kategoria',
    'restore_product' => 'Przywróć produkt',
    'blank' => 'Puste',
    'invoice_save_error' => 'Wystąpił błąd w trakcie zapisywania faktury',
    'enable_recurring' => 'Aktywuj okresowość',
    'disable_recurring' => 'Wyłącz okresowość',
    'text' => 'Tekst',
    'expense_will_create' => 'wydatek zostanie utworzony',
    'expenses_will_create' => 'wydatki zostaną utworzone',
    'created_expenses' => 'Utworzono :count wydatek(ów)',

    'translate_app' => 'Możesz pomóc nam w tłumaczeniu :link',
    'expense_category' => 'Kategoria wydatku',

    'go_ninja_pro' => 'Wybierz Ninja Pro!',
    'go_enterprise' => 'Wybierz Enterprise!',
    'upgrade_for_features' => 'Przejdź na wyższą wersję dla wielu nowych funkcjonalności',
    'pay_annually_discount' => 'Zapłać rocznie za 10 miesięcy + 2 miesiące gratis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'TwojaNazwa.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Dostosuj faktury do swoich potrzeb!',
    'enterprise_upgrade_feature1' => 'Ustaw prawa dostępu dla wielu użytkowników',
    'enterprise_upgrade_feature2' => 'Dołączaj dodatkowe pliki do faktur i wydatków',
    'much_more' => 'Znacznie więcej!',
    'all_pro_fetaures' => 'Plus all pro features!',

    'currency_symbol' => 'Symbol',
    'currency_code' => 'Kod',

    'buy_license' => 'Kup licencję',
    'apply_license' => 'Zastosuj licencję',
    'submit' => 'Wyślij',
    'white_label_license_key' => 'Klucz licencyjny',
    'invalid_white_label_license' => 'Licencja White Label nie jest ważna',
    'created_by' => 'Utworzono przez :name',
    'modules' => 'Moduły',
    'financial_year_start' => 'Pierwszy miesiąc roku',
    'authentication' => 'Autentykacja',
    'checkbox' => 'Przycisk wyboru',
    'invoice_signature' => 'Podpis',
    'show_accept_invoice_terms' => 'Przycisk wyboru do warunków faktury',
    'show_accept_invoice_terms_help' => 'Wymagaj od klienta potwierdzenia, że akceptuje warunki faktury.',
    'show_accept_quote_terms' => 'Przycisk wyboru do warunków oferty',
    'show_accept_quote_terms_help' => 'Wymagaj od klienta potwierdzenia, że akceptuje warunki oferty.',
    'require_invoice_signature' => 'Podpis na fakurze',
    'require_invoice_signature_help' => 'Wymagaj od klienta podpisania faktury',
    'require_quote_signature' => 'Podpis na ofercie',
    'require_quote_signature_help' => 'Wymagaj od klienta jego podpisu.',
    'i_agree' => 'Zgadzam się z warunkami',
    'sign_here' => 'Proszę podpisać tutaj:',
    'authorization' => 'Autoryzacja',
    'signed' => 'Podpisano',

    // BlueVine
    'bluevine_promo' => 'Otrzymaj elastyczne biznesowe linie kredytowe oraz obsługę faktur dzięki BlueVine.',
    'bluevine_modal_label' => 'Zarejestruj się w BlueVine',
    'bluevine_modal_text' => '<h3>Fast funding for your business. No paperwork.</h3>
<ul><li>Flexible business lines of credit and invoice factoring.</li></ul>',
    'bluevine_create_account' => 'Stwórz konto',
    'quote_types' => 'Otrzymaj ofertę dla',
    'invoice_factoring' => 'Generowanie faktur',
    'line_of_credit' => 'Linia kredytowa',
    'fico_score' => 'Twoja ocena FICO',
    'business_inception' => 'Business Inception Date',
    'average_bank_balance' => 'Średnie saldo bankowe',
    'annual_revenue' => 'Roczny przychód',
    'desired_credit_limit_factoring' => 'Wybrany limit generowania faktur',
    'desired_credit_limit_loc' => 'Wybrany limit linii kredytowej',
    'desired_credit_limit' => 'Wybrany limit kredytowy',
    'bluevine_credit_line_type_required' => 'Musisz wybrać przynajmniej jedną opcję',
    'bluevine_field_required' => 'To pole jest wymagane',
    'bluevine_unexpected_error' => 'Wystąpił nieznany błąd.',
    'bluevine_no_conditional_offer' => 'Do otrzymania oferty wymagane jest więcej informacji. Kliknij "kontynuuj" poniżej.',
    'bluevine_invoice_factoring' => 'Generowanie faktur',
    'bluevine_conditional_offer' => 'Oferta pod określonymi warunkami',
    'bluevine_credit_line_amount' => 'Linia kredytowa',
    'bluevine_advance_rate' => 'Zaawansowany przelicznik',
    'bluevine_weekly_discount_rate' => 'Tygodniowa stopa rabatu',
    'bluevine_minimum_fee_rate' => 'Minimalna opłata',
    'bluevine_line_of_credit' => 'Linia Kredytu',
    'bluevine_interest_rate' => 'Interest Rate',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'Przejdź do BlueVine',
    'bluevine_completed' => 'Rejestracja w BlueVine ukończona',

    'vendor_name' => 'Dostawca',
    'entity_state' => 'Stan',
    'client_created_at' => 'Data utworzenia',
    'postmark_error' => 'Wystąpił błąd w trakcie wysyłania wiadomości email przez Postmark: :link',
    'project' => 'Projekt',
    'projects' => 'Projekty',
    'new_project' => 'Nowy projekt',
    'edit_project' => 'Edytuj projekt',
    'archive_project' => 'Zarchiwizuj produkt',
    'list_projects' => 'Lista produktów',
    'updated_project' => 'Zaktualizowano projekt',
    'created_project' => 'Utworzono projekt',
    'archived_project' => 'Zarchiwizowano projekt',
    'archived_projects' => 'Zarchiwizowano :count projektów',
    'restore_project' => 'Przywróć projekt',
    'restored_project' => 'Przywrócono projekt',
    'delete_project' => 'Usuń projekt',
    'deleted_project' => 'Usunięto projekt',
    'deleted_projects' => 'Usunięto :count projekty/projektów',
    'delete_expense_category' => 'Usuń kategorię',
    'deleted_expense_category' => 'Usunięto kategorię',
    'delete_product' => 'Usuń produkt',
    'deleted_product' => 'Usunięto produkt',
    'deleted_products' => 'Usunięto :count produktów',
    'restored_product' => 'Przywrócono produkt',
    'update_credit' => 'Aktualizuj kredyt',
    'updated_credit' => 'Zaktualizowano kredyt',
    'edit_credit' => 'Edytuj kredyt',
    'realtime_preview' => 'Podgląd w czasie rzeczywistym',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'Zastąp wbudowany podgląd plików PDF w :chrome_link i :firefox_link.<br/>Włącz tę opcję, jeśli przeglądarka automatycznie pobiera plik PDF.',
    'force_pdfjs' => 'Prevent Download',
    'redirect_url' => 'URL przekierowania',
    'redirect_url_help' => 'Opcjonalnie określ adres URL do przekierowania po wprowadzeniu płatności.',
    'save_draft' => 'Zapisz wersję roboczą',
    'refunded_credit_payment' => 'Zwrócona płatność kredytowa',
    'keyboard_shortcuts' => 'Skróty klawiaturowe',
    'toggle_menu' => 'Przełącz menu',
    'new_...' => 'Nowy ...',
    'list_...' => 'Lista ...',
    'created_at' => 'Data utworzenia',
    'contact_us' => 'Skontaktuj się z nami',
    'user_guide' => 'Przewodnik użytkownika',
    'promo_message' => 'Przejdź na wyższą wersję przez :expires i zyskaj :amount zniżki za pierwszy rok planu Pro lub Enterprise.',
    'discount_message' => ':amount wygasa :expires',
    'mark_paid' => 'Oznacz jako zapłaconą',
    'marked_sent_invoice' => 'Oznaczono fakturę jako wysłaną',
    'marked_sent_invoices' => 'Oznaczono faktury jako wysłane',
    'invoice_name' => 'Faktura',
    'product_will_create' => 'produkt zostanie stworzony',
    'contact_us_response' => 'Dziękujemy za Twoją wiadomość! Postaramy się odpowiedzieć tak szybko jak to możliwe.',
    'last_7_days' => 'Ostatnie 7 dni',
    'last_30_days' => 'Ostatnie 30 dni',
    'this_month' => 'Ten miesiąc',
    'last_month' => 'Ostatni miesiąc',
    'current_quarter' => 'Obecny kwartał',
    'last_quarter' => 'Poprzedni kwartał',
    'last_year' => 'Ostatni rok',
    'custom_range' => 'Określony okres',
    'url' => 'URL',
    'debug' => 'Debugowanie',
    'https' => 'HTTPS',
    'require' => 'Wymagaj',
    'license_expiring' => 'Uwaga: Twoja licencja wygasa za :count dni. :link, aby ją odnowić.',
    'security_confirmation' => 'Twój adres email został potwierdzony.',
    'white_label_expired' => 'Licencja White Label wygasła. Proszę rozważyć odnowienie jej, aby wspierać rozwój naszego projektu.',
    'renew_license' => 'Odnów licencję',
    'iphone_app_message' => 'Rozważ pobranie od nas :link',
    'iphone_app' => 'Aplikacja iPhone',
    'android_app' => 'Android app',
    'logged_in' => 'Zalogowany',
    'switch_to_primary' => 'Przełącz się na swoją główną firmę (:name), aby zarządzać planem.',
    'inclusive' => 'Wliczanie w kwotę',
    'exclusive' => 'Doliczanie do kwoty',
    'postal_city_state' => 'Kod pocztowy/Miasto/Województwo',
    'phantomjs_help' => 'W pewnym okolicznościach aplikacja używa :link_phantom do generowania plików PDF. Zainstaluj :link_docs, aby móc generować je lokalnie.',
    'phantomjs_local' => 'Użycie lokalnego PhantomJS',
    'client_number' => 'Numer klienta',
    'client_number_help' => 'Proszę określić prefiks lub dostosować wzór aby automatycznie ustawiać numer klienta.',
    'next_client_number' => 'Numerem następnego klienta będzie :number.',
    'generated_numbers' => 'Wygenerowane numery',
    'notes_reminder1' => 'Pierwsze przypomnienie',
    'notes_reminder2' => 'Drugie przypomnienie',
    'notes_reminder3' => 'Trzecie przypomienie',
    'notes_reminder4' => 'Przypomnienie',
    'bcc_email' => 'UDW Email',
    'tax_quote' => 'Podatek do oferty',
    'tax_invoice' => 'Podatek do faktury',
    'emailed_invoices' => 'Wysyłka maili powiodła się',
    'emailed_quotes' => 'Wysyłka ofert powiodła się',
    'website_url' => 'Adres strony www',
    'domain' => 'Domena',
    'domain_help' => 'Używany w portalu klienta oraz przy wysyłce wiadomości email.',
    'domain_help_website' => 'Używane przy wysyłaniu wiadomości email.',
    'import_invoices' => 'Importuj faktury',
    'new_report' => 'Nowy raport',
    'edit_report' => 'Edytuj raport',
    'columns' => 'Kolumny',
    'filters' => 'Filtry',
    'sort_by' => 'Sortowanie po',
    'draft' => 'Wersja robocza',
    'unpaid' => 'Nie zapłacono',
    'aging' => 'Odkładanie',
    'age' => 'Wiek',
    'days' => 'Dni',
    'age_group_0' => '0 - 30 dni',
    'age_group_30' => '30 - 60 dni',
    'age_group_60' => '60 - 90 dni',
    'age_group_90' => '90 - 120 dni',
    'age_group_120' => 'ponad 120 dni',
    'invoice_details' => 'Szczegóły faktury',
    'qty' => 'Ilość',
    'profit_and_loss' => 'Zysk i strata',
    'revenue' => 'Dochód',
    'profit' => 'Zysk',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'Grupuj daty po',
    'year' => 'Rok',
    'view_statement' => 'Zobacz wyciąg',
    'statement' => 'Wyciąg',
    'statement_date' => 'Data wygenerowania wyciągu',
    'mark_active' => 'Oznacz jako aktywną',
    'send_automatically' => 'Wyślij automatycznie',
    'initial_email' => 'Początkowy email',
    'invoice_not_emailed' => 'Ta faktura nie została wysłana emailem.',
    'quote_not_emailed' => 'Ta oferta nie została wysłana emailem.',
    'sent_by' => 'Wysłano przez :user',
    'recipients' => 'Odbiorcy',
    'save_as_default' => 'Zapisz jako domyślne',
    'start_of_week_help' => 'Używany przez selektory <b>dat</b>',
    'financial_year_start_help' => 'Używany przez selektory <b>zakresów czasu</b>',
    'reports_help' => 'Shift + LPM aby sortować po wielu kolumnach. Ctrl + LPM aby usunąć grupowanie.',
    'this_year' => 'Ten rok',

    // Updated login screen
    'ninja_tagline' => 'Twórz. Wysyłaj. Zarabiaj.',
    'login_or_existing' => 'Or login with a connected account.',
    'sign_up_now' => 'Zarejestruj się teraz.',
    'not_a_member_yet' => 'Nie masz konta?',
    'login_create_an_account' => 'Stwórz konto!',

    // New Client Portal styling
    'invoice_from' => 'Sprzedawca:',
    'email_alias_message' => 'We require each company to have a unique email address.<br/>Consider using an alias. ie, email+label@example.com',
    'full_name' => 'Pełna nazwa',
    'month_year' => 'MIESIĄC/ROK',
    'valid_thru' => 'Ważna\nprzez',

    'product_fields' => 'Pola produktów',
    'custom_product_fields_help' => 'Dodaj pole przy tworzeniu produktu lub faktury i wyświetlaj jego etykietę oraz wartość w pliku PDF.',
    'freq_two_months' => 'Dwa miesiące',
    'freq_yearly' => 'Rocznie',
    'profile' => 'Profil',
    'payment_type_help' => 'Ustaw jako domyślny <b>rodzaj płatności</b>',
    'industry_Construction' => 'Budownictwo',
    'your_statement' => 'Twój wyciąg',
    'statement_issued_to' => 'Wykaz wystawiony dla',
    'statement_to' => 'Wykaz dla',
    'customize_options' => 'Dostosuj opcje',
    'created_payment_term' => 'Utworzono termin płatności',
    'updated_payment_term' => 'Zaktualizowano termin płatności',
    'archived_payment_term' => 'Zarchiwizowano termin płatności',
    'resend_invite' => 'Ponów zaproszenie',
    'credit_created_by' => 'Kredyt stworzony przez płatność :transaction_reference',
    'created_payment_and_credit' => 'Utworzono płatność i kredyt.',
    'created_payment_and_credit_emailed_client' => 'Utworzono płatność, kredyt i wysłano email do klienta',
    'create_project' => 'Utwórz projekt',
    'create_vendor' => 'Utwórz dostawcę',
    'create_expense_category' => 'Utwórz kategorię',
    'pro_plan_reports' => ':link aby aktywować raporty dołącz do planu Pro',
    'mark_ready' => 'Oznacz jako gotową',

    'limits' => 'Limity',
    'fees' => 'Opłaty',
    'fee' => 'Opłata',
    'set_limits_fees' => 'Ustaw limity/opłaty dla płatności typu :gateway_type ',
    'fees_tax_help' => 'Umożliwia podatkom dopisanym do poszczególnych pozycji na ustawianie podatków od opłat.',
    'fees_sample' => 'Opłata do faktury :amount wynosić będzie :total.',
    'discount_sample' => 'Rabat z kwoty :amount faktury wyniesie w sumie :total.',
    'no_fees' => 'Brak opłat',
    'gateway_fees_disclaimer' => 'Ostrzeżenie: nie wszystkie kraje/dostawcy płatności zezwalają na dodatkowe opłaty. Proszę sprawdzić lokalne przepisy/warunki świadczenia usług.',
    'percent' => 'Procent',
    'location' => 'Lokalizacja',
    'line_item' => 'Element na liście',
    'surcharge' => 'Dopłata',
    'location_first_surcharge' => 'Aktywowano - pierwsza dopłata',
    'location_second_surcharge' => 'Aktywowano - druga dopłata',
    'location_line_item' => 'Aktywowano - trzecia dopłata',
    'online_payment_surcharge' => 'Dopłata za płatność online',
    'gateway_fees' => 'Opłaty dostawcy płatności',
    'fees_disabled' => 'Dodatkowe opłaty są wyłączone',
    'gateway_fees_help' => 'Automatically add an online payment surcharge/discount.',
    'gateway' => 'Dostawca płatności',
    'gateway_fee_change_warning' => 'If there are unpaid invoices with fees they need to be updated manually.',
    'fees_surcharge_help' => 'Dostosuj dopłaty :link.',
    'label_and_taxes' => 'etykiety i podatki',
    'billable' => 'Opłacany',
    'logo_warning_too_large' => 'Przesłany plik obrazu jest zbyt duży.',
    'logo_warning_fileinfo' => 'Ostrzeżenie: do obsługi plików GIF wymagane jest rozszerzenie PHP o nazwie fileinfo.',
    'logo_warning_invalid' => 'Wystąpił błąd w trakcie przetwarzania pliku. Proszę spróbować przesłać plik w innym formacie.',

    'error_refresh_page' => 'Wystąpił błąd. Proszę odświeżyć stronę i spróbować ponownie.',
    'data' => 'Dane',
    'imported_settings' => 'Udało się zaimportować ustawienia',
    'reset_counter' => 'Zresetuj licznik',
    'next_reset' => 'Następny reset',
    'reset_counter_help' => 'Automatycznie resetuj liczniki faktur i ofert.',
    'auto_bill_failed' => 'Auto-billing for invoice :invoice_number failed',
    'online_payment_discount' => 'Online Payment Discount',
    'created_new_company' => 'Successfully created new company',
    'fees_disabled_for_gateway' => 'Fees are disabled for this gateway.',
    'logout_and_delete' => 'Log Out/Delete Account',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'Use $pageNumber and $pageCount to display the page information.',
    'credit_note' => 'Credit Note',
    'credit_issued_to' => 'Credit issued to',
    'credit_to' => 'Credit to',
    'your_credit' => 'Twój kredyt',
    'credit_number' => 'Credit Number',
    'create_credit_note' => 'Create Credit Note',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Error: The gateways table has incorrect ids.',
    'purge_data' => 'Purge Data',
    'delete_data' => 'Delete Data',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'Permanently delete the account along with all data and setting.',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'Forbidden',
    'purge_data_message' => 'Warning: This will permanently erase your data, there is no undo.',
    'contact_phone' => 'Numer telefonu kontaktu',
    'contact_email' => 'Email kontaktowy',
    'reply_to_email' => 'Odpowiedz do:',
    'reply_to_email_help' => 'Wpisz adres email klienta na który będziemy odpowiadać.',
    'bcc_email_help' => 'Privately include this address with client emails.',
    'import_complete' => 'Your import has successfully completed.',
    'confirm_account_to_import' => 'Potwierdź swoje konto, żeby zaimportować dane',
    'import_started' => 'Twój import danych został zainicjowany, kiedy się zakończy zostaniesz poinformowany mailowo.',
    'listening' => 'Listening...',
    'microphone_help' => 'Say "new invoice for [client]" or "show me [client]\'s archived payments"',
    'voice_commands' => 'Voice Commands',
    'sample_commands' => 'Sample commands',
    'voice_commands_feedback' => 'We\'re actively working to improve this feature, if there\'s a command you\'d like us to support please email us at :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => 'Successfully archived :count products',
    'recommend_on' => 'We recommend <b>enabling</b> this setting.',
    'recommend_off' => 'We recommend <b>disabling</b> this setting.',
    'notes_auto_billed' => 'Auto-billed',
    'surcharge_label' => 'Surcharge Label',
    'contact_fields' => 'Contact Fields',
    'custom_contact_fields_help' => 'Add a field when creating a contact and optionally display the label and value on the PDF.',
    'datatable_info' => 'Showing :start to :end of :total entries',
    'credit_total' => 'Credit Total',
    'mark_billable' => 'Oznacz jako rozliczalne',
    'billed' => 'Billed',
    'company_variables' => 'Company Variables',
    'client_variables' => 'Client Variables',
    'invoice_variables' => 'Invoice Variables',
    'navigation_variables' => 'Navigation Variables',
    'custom_variables' => 'Custom Variables',
    'invalid_file' => 'Invalid file type',
    'add_documents_to_invoice' => 'Dodaj dokumenty do faktury',
    'mark_expense_paid' => 'Oznacz jako zapłacony',
    'white_label_license_error' => 'Failed to validate the license, check storage/logs/laravel-error.log for more details.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation code',
    'oauth_taken' => 'The account is already registered',
    'emailed_payment' => 'Successfully emailed payment',
    'email_payment' => 'Email Payment',
    'invoiceplane_import' => 'Use :link to migrate your data from InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: This :link may be a duplicate',
    'expense_link' => 'expense',
    'resume_task' => 'Resume Task',
    'resumed_task' => 'Successfully resumed task',
    'quote_design' => 'Quote Design',
    'default_design' => 'Standard Design',
    'custom_design1' => 'Custom Design 1',
    'custom_design2' => 'Custom Design 2',
    'custom_design3' => 'Custom Design 3',
    'empty' => 'Empty',
    'load_design' => 'Load Design',
    'accepted_card_logos' => 'Accepted Card Logos',
    'phantomjs_local_and_cloud' => 'Using local PhantomJS, falling back to phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Track payments using :link',
    'start_date_required' => 'The start date is required',
    'application_settings' => 'Application Settings',
    'database_connection' => 'Database Connection',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Test connection',
    'from_name' => 'From Name',
    'from_address' => 'From Address',
    'port' => 'Port',
    'encryption' => 'Encryption',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Send test email',
    'select_label' => 'Select Label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Update payment details',
    'updated_payment_details' => 'Successfully updated payment details',
    'update_credit_card' => 'Update Credit Card',
    'recurring_expenses' => 'Recurring Expenses',
    'recurring_expense' => 'Recurring Expense',
    'new_recurring_expense' => 'New Recurring Expense',
    'edit_recurring_expense' => 'Edit Recurring Expense',
    'archive_recurring_expense' => 'Archive Recurring Expense',
    'list_recurring_expense' => 'List Recurring Expenses',
    'updated_recurring_expense' => 'Successfully updated recurring expense',
    'created_recurring_expense' => 'Successfully created recurring expense',
    'archived_recurring_expense' => 'Successfully archived recurring expense',
    'restore_recurring_expense' => 'Restore Recurring Expense',
    'restored_recurring_expense' => 'Successfully restored recurring expense',
    'delete_recurring_expense' => 'Delete Recurring Expense',
    'deleted_recurring_expense' => 'Successfully deleted project',
    'view_recurring_expense' => 'View Recurring Expense',
    'taxes_and_fees' => 'Taxes and fees',
    'import_failed' => 'Import Failed',
    'recurring_prefix' => 'Recurring Prefix',
    'options' => 'Options',
    'credit_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the credit number for negative invoices.',
    'next_credit_number' => 'The next credit number is :number.',
    'padding_help' => 'The number of zero\'s to pad the number.',
    'import_warning_invalid_date' => 'Warning: The date format appears to be invalid.',
    'product_notes' => 'Product Notes',
    'app_version' => 'App Version',
    'ofx_version' => 'OFX Version',
    'gateway_help_23' => ':link to get your Stripe API keys.',
    'error_app_key_set_to_default' => 'Error: APP_KEY is set to a default value, to update it backup your database and then run <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Charge Late Fee',
    'late_fee_amount' => 'Late Fee Amount',
    'late_fee_percent' => 'Late Fee Percent',
    'late_fee_added' => 'Late fee added on :date',
    'download_invoice' => 'Pobierz fakturę',
    'download_quote' => 'Download Quote',
    'invoices_are_attached' => 'Faktura PDF została załączona',
    'downloaded_invoice' => 'An email will be sent with the invoice PDF',
    'downloaded_quote' => 'An email will be sent with the quote PDF',
    'downloaded_invoices' => 'An email will be sent with the invoice PDFs',
    'downloaded_quotes' => 'An email will be sent with the quote PDFs',
    'clone_expense' => 'Clone Expense',
    'default_documents' => 'Domyślne dokumenty',
    'send_email_to_client' => 'Send email to the client',
    'refund_subject' => 'Refund Processed',
    'refund_body' => 'You have been processed a refund of :amount for invoice :invoice_number.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'British Pound',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Złoty polski',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'Make sure to use the English version of the files.<br/>We use the column headers to match the fields.',
    'tax1' => 'First Tax',
    'tax2' => 'Second Tax',
    'fee_help' => 'Gateway fees are the costs charged for access to the financial networks that handle the processing of online payments.',
    'format_export' => 'Exporting format',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Contact First Name',
    'contact_last_name' => 'Contact Last Name',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Waluta',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'comments',

    'item_product' => 'Item Product',
    'item_notes' => 'Item Notes',
    'item_cost' => 'Item Cost',
    'item_quantity' => 'Item Quantity',
    'item_tax_rate' => 'Item Tax Rate',
    'item_tax_name' => 'Item Tax Name',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Delete Company',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Warning: This will permanently delete your company, there is no undo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Include Errors',
    'include_errors_help' => 'Include :link from storage/logs/laravel-error.log',
    'recent_errors' => 'recent errors',
    'customer' => 'Customer',
    'customers' => 'Customers',
    'created_customer' => 'Successfully created customer',
    'created_customers' => 'Successfully created :count customers',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Your company (:account) has been successfully deleted.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Accept EU bank transfers',
    'stripe_alipay_help' => 'These gateways also need to be activated in :link.',
    'calendar' => 'Kalendarz',
    'pro_plan_calendar' => ':link to enable the calendar by joining the Pro Plan',

    'what_are_you_working_on' => 'Nad czym pracujesz?',
    'time_tracker' => 'Śledzenie czasu',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'No Description',
    'time_tracker_login' => 'Logowanie do śledzenia czasu',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tasks are not enabled.',
    'started_task' => 'Successfully started task',
    'create_client' => 'Create Client',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Download the iPhone app',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Double tap a task to select it',
    'stopped' => 'Stopped',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
    'sort_field' => 'Sort By',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Stawka zadania',
    'task_rate_help' => 'Ustaw domyślną stawkę dla zafakturowanych zadań.',
    'past_due' => 'Po terminie',
    'document' => 'Dokument',
    'invoice_or_expense' => 'Invoice/Expense',
    'invoice_pdfs' => 'Invoice PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Recover License',
    'purchase' => 'Purchase',
    'recover' => 'Recover',
    'apply' => 'Zastosuj',
    'recover_white_label_header' => 'Recover White Label License',
    'apply_white_label_header' => 'Zastosuj licencję białej etykiety',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Return to Invoice',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Task Fields',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Custom Value',
    'custom_value2' => 'Custom Value',
    'enable_two_factor' => 'Two-Factor Authentication',
    'enable_two_factor_help' => 'Use your phone to confirm your identity when logging in',
    'two_factor_setup' => 'Two-Factor Setup',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'One Time Password',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Successfully enabled Two-Factor Authentication',
    'add_product' => 'Add Product',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Invoice Product',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Your Password Reset Link',
    'subdomain_taken' => 'The subdomain is already in use',
    'client_login' => 'Logowanie klienta',
    'converted_amount' => 'Kwota przeliczona',
    'default' => 'Default',
    'shipping_address' => 'Shipping Address',
    'bllling_address' => 'Billing Address',
    'billing_address1' => 'Billing Street',
    'billing_address2' => 'Billing Apt/Suite',
    'billing_city' => 'Billing City',
    'billing_state' => 'Billing State/Province',
    'billing_postal_code' => 'Billing Postal Code',
    'billing_country' => 'Billing Country',
    'shipping_address1' => 'Shipping Street',
    'shipping_address2' => 'Shipping Apt/Suite',
    'shipping_city' => 'Shipping City',
    'shipping_state' => 'Shipping State/Province',
    'shipping_postal_code' => 'Shipping Postal Code',
    'shipping_country' => 'Shipping Country',
    'classify' => 'Classify',
    'show_shipping_address_help' => 'Require client to provide their shipping address',
    'ship_to_billing_address' => 'Ship to billing address',
    'delivery_note' => 'Dowód dostawy',
    'show_tasks_in_portal' => 'Show tasks in the client portal',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled Report',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Invalid one time password',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay and Pay with Google',
    'requires_subdomain' => 'This payment type requires that a :link.',
    'subdomain_is_set' => 'subdomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification file is needed to accept payments.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay isn\'t supported by your browser',
    'optional_payment_methods' => 'Optional Payment Methods',
    'add_subscription' => 'Add Subscription',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'Created Client',
    'subscription_event_2' => 'Created Invoice',
    'subscription_event_3' => 'Created Quote',
    'subscription_event_4' => 'Created Payment',
    'subscription_event_5' => 'Created Vendor',
    'subscription_event_6' => 'Updated Quote',
    'subscription_event_7' => 'Deleted Quote',
    'subscription_event_8' => 'Updated Invoice',
    'subscription_event_9' => 'Deleted Invoice',
    'subscription_event_10' => 'Updated Client',
    'subscription_event_11' => 'Deleted Client',
    'subscription_event_12' => 'Deleted Payment',
    'subscription_event_13' => 'Updated Vendor',
    'subscription_event_14' => 'Deleted Vendor',
    'subscription_event_15' => 'Created Expense',
    'subscription_event_16' => 'Updated Expense',
    'subscription_event_17' => 'Deleted Expense',
    'subscription_event_18' => 'Created Task',
    'subscription_event_19' => 'Updated Task',
    'subscription_event_20' => 'Deleted Task',
    'subscription_event_21' => 'Approved Quote',
    'subscriptions' => 'Subscriptions',
    'updated_subscription' => 'Successfully updated subscription',
    'created_subscription' => 'Successfully created subscription',
    'edit_subscription' => 'Edit Subscription',
    'archive_subscription' => 'Archive Subscription',
    'archived_subscription' => 'Successfully archived subscription',
    'project_error_multiple_clients' => 'The projects can\'t belong to different clients',
    'invoice_project' => 'Invoice Project',
    'module_recurring_invoice' => 'Recurring Invoices',
    'module_credit' => 'Credits',
    'module_quote' => 'Oferty i propozycje',
    'module_task' => 'Tasks & Projects',
    'module_expense' => 'Expenses & Vendors',
    'module_ticket' => 'Tickets',
    'reminders' => 'Przypomnienia',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'Tasks are visible in the portal',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Please register your account',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Include <b>taxes in the cost</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Copy Shipping',
    'copy_billing' => 'Copy Billing',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Showing 0 to 0 of 0 entries',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Trust for 30 days',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Add status',
    'archive_status' => 'Archive Status',
    'new_status' => 'New Status',
    'convert_products' => 'Convert Products',
    'convert_products_help' => 'Automatycznie zamieniaj ceny produktu na walutę klienta',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Budgeted Hours',
    'progress' => 'Progress',
    'view_project' => 'View Project',
    'summary' => 'Summary',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Show on PDF',
    'signature_on_pdf_help' => 'Show the client signature on the invoice/quote PDF.',
    'expired_white_label' => 'The white label license has expired',
    'return_to_login' => 'Return to Login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Client Information',
    'updated_client_details' => 'Successfully updated client details',
    'auto' => 'Auto',
    'tax_amount' => 'Podatek',
    'tax_paid' => 'Podatek zapłacony',
    'none' => 'None',
    'proposal_message_button' => 'Aby wyświetlić propozycję dla :amount, kliknij przycisk poniżej.',
    'proposal' => 'Propozycja',
    'proposals' => 'Propozycje',
    'list_proposals' => 'Lista propozycji',
    'new_proposal' => 'Nowa propozycja',
    'edit_proposal' => 'Edytuj propozycję',
    'archive_proposal' => 'Archiwizuj propozycję',
    'delete_proposal' => 'Usuń propozycję',
    'created_proposal' => 'Propozycja została pomyślnie utworzona',
    'updated_proposal' => 'Propozycja została pomyślnie zaktualizowana',
    'archived_proposal' => 'Propozycja została pomyślnie zarchiwizowana',
    'deleted_proposal' => 'Successfully archived proposal',
    'archived_proposals' => 'Successfully archived :count proposals',
    'deleted_proposals' => 'Successfully archived :count proposals',
    'restored_proposal' => 'Propozycja została przywrócona',
    'restore_proposal' => 'Przywróć propozycję',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Szablon',
    'templates' => 'Templates',
    'proposal_template' => 'Template',
    'proposal_templates' => 'Templates',
    'new_proposal_template' => 'New Template',
    'edit_proposal_template' => 'Edit Template',
    'archive_proposal_template' => 'Archive Template',
    'delete_proposal_template' => 'Delete Template',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Category',
    'proposal_categories' => 'Categories',
    'new_proposal_category' => 'New Category',
    'edit_proposal_category' => 'Edit Category',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'Żądana propozycja nie jest dostępna',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Email propozycji',
    'proposal_subject' => 'Nowa propozycja :number od :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Grupuj',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'Zobacz propozycję',
    'view_in_portal' => 'Zobacz w portalu',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Numer referencyjny płatności',
    'maximum' => 'Maximum',
    'sort' => 'Sortuj',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Podsumowanie',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Uruchom ponownie aplikację, aby zastosować zmianę',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Rozmiar',
    'net' => 'Net',
    'show_tasks' => 'Pokaż zadania',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'Więcej',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Edit Recurring Quote',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priorytet',
    'last_updated' => 'Last Updated',
    'comment' => 'Komentarze',
    'tags' => 'Tagi',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Odpowiedz',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Obecny',
    'previous' => 'Poprzedni',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Średnia',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Ważny do',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Dni',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Zrób zdjęcie',
    'upload_file' => 'Upload File',
    'new_document' => 'Nowy dokument',
    'edit_document' => 'Edytuj dokument',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Prześlij logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Ustawienia urządzenia',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Cena',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'Wyświetl PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Zaloguj się przez email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Szukaj w firmie',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Zaloguj się przez Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Zakończone',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'Ten kwartał',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
